@@ -5,13 +5,14 @@
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
-from ansible_collections.arista.eos.tests.unit.compat.mock import patch
+from unittest.mock import patch
+
 from ansible_collections.arista.eos.plugins.modules import eos_bgp_global
-from ansible_collections.arista.eos.tests.unit.modules.utils import (
-    set_module_args,
-)
+from ansible_collections.arista.eos.tests.unit.modules.utils import set_module_args
+
 from .eos_module import TestEosModule, load_fixture
 
 
@@ -22,23 +23,19 @@ class TestEosBgpglobalModule(TestEosModule):
         super(TestEosBgpglobalModule, self).setUp()
 
         self.mock_get_resource_connection_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.resource_module_base.get_resource_connection"
-        )
-        self.get_resource_connection_config = (
-            self.mock_get_resource_connection_config.start()
+            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.resource_module_base.get_resource_connection",
         )
+        self.get_resource_connection_config = self.mock_get_resource_connection_config.start()
 
         self.mock_execute_show_command = patch(
-            "ansible_collections.arista.eos.plugins.module_utils.network.eos.facts.bgp_global.bgp_global.Bgp_globalFacts.get_config"
+            "ansible_collections.arista.eos.plugins.module_utils.network.eos.facts.bgp_global.bgp_global.Bgp_globalFacts.get_config",
         )
         self.execute_show_command = self.mock_execute_show_command.start()
 
         self.mock_execute_show_command_config = patch(
-            "ansible_collections.arista.eos.plugins.module_utils.network.eos.config.bgp_global.bgp_global.Bgp_global._get_config"
-        )
-        self.execute_show_command_config = (
-            self.mock_execute_show_command_config.start()
+            "ansible_collections.arista.eos.plugins.module_utils.network.eos.config.bgp_global.bgp_global.Bgp_global._get_config",
         )
+        self.execute_show_command_config = self.mock_execute_show_command_config.start()
 
     def tearDown(self):
         super(TestEosBgpglobalModule, self).tearDown()
@@ -80,7 +77,8 @@ class TestEosBgpglobalModule(TestEosModule):
                             peer_group="peer2",
                             maximum_received_routes=dict(count=12000),
                             encryption_password=dict(
-                                password="mypassword", type=0
+                                password="mypassword",
+                                type=0,
                             ),
                         ),
                     ],
@@ -104,23 +102,24 @@ class TestEosBgpglobalModule(TestEosModule):
                             default_metric=433,
                             network=[
                                 dict(
-                                    address="6.6.6.0/24", route_map="netmap1"
+                                    address="6.6.6.0/24",
+                                    route_map="netmap1",
                                 ),
                                 dict(address="10.1.0.0/16"),
                             ],
                             redistribute=[
-                                dict(protocol="isis", isis_level="level-2")
+                                dict(protocol="isis", isis_level="level-2"),
                             ],
                             route_target=dict(
                                 action="export",
                                 type="vpn-ipv4",
                                 target="44:22",
                             ),
-                        )
+                        ),
                     ],
                 ),
                 state="merged",
-            )
+            ),
         )
         self.execute_module(changed=False, commands=[])
 
@@ -130,7 +129,8 @@ class TestEosBgpglobalModule(TestEosModule):
                 config=dict(
                     as_number="65535",
                     maximum_paths=dict(
-                        max_equal_cost_paths=32, max_installed_ecmp_paths=32
+                        max_equal_cost_paths=32,
+                        max_installed_ecmp_paths=32,
                     ),
                     vrfs=[
                         dict(
@@ -139,7 +139,8 @@ class TestEosBgpglobalModule(TestEosModule):
                                 listen=dict(limit=20),
                                 log_neighbor_changes=True,
                                 missing_policy=dict(
-                                    direction="in", action="deny"
+                                    direction="in",
+                                    action="deny",
                                 ),
                                 monitoring=True,
                                 next_hop_unchanged=True,
@@ -151,8 +152,9 @@ class TestEosBgpglobalModule(TestEosModule):
                             timers=dict(keepalive=44, holdtime=100),
                             ucmp=dict(
                                 link_bandwidth=dict(
-                                    mode="update_delay", update_delay=10
-                                )
+                                    mode="update_delay",
+                                    update_delay=10,
+                                ),
                             ),
                             neighbors=[
                                 dict(
@@ -179,7 +181,7 @@ class TestEosBgpglobalModule(TestEosModule):
                                     shutdown=True,
                                 ),
                             ],
-                        )
+                        ),
                     ],
                     default_metric=433,
                     networks=[
@@ -190,11 +192,12 @@ class TestEosBgpglobalModule(TestEosModule):
                     route_target=dict(action="export", target="44:22"),
                     ucmp=dict(mode=dict(nexthops=55)),
                     update=dict(
-                        wait_for="wait_for_convergence", batch_size=50
+                        wait_for="wait_for_convergence",
+                        batch_size=50,
                     ),
                 ),
                 state="merged",
-            )
+            ),
         )
         commands = [
             "router bgp 65535",
@@ -258,7 +261,8 @@ class TestEosBgpglobalModule(TestEosModule):
                             peer_group="peer2",
                             maximum_received_routes=dict(count=12000),
                             encryption_password=dict(
-                                password="mypassword", type=0
+                                password="mypassword",
+                                type=0,
                             ),
                         ),
                     ],
@@ -282,23 +286,24 @@ class TestEosBgpglobalModule(TestEosModule):
                             default_metric=433,
                             network=[
                                 dict(
-                                    address="6.6.6.0/24", route_map="netmap1"
+                                    address="6.6.6.0/24",
+                                    route_map="netmap1",
                                 ),
                                 dict(address="10.1.0.0/16"),
                             ],
                             redistribute=[
-                                dict(protocol="isis", isis_level="level-2")
+                                dict(protocol="isis", isis_level="level-2"),
                             ],
                             route_target=dict(
                                 action="export",
                                 type="vpn-ipv4",
                                 target="44:22",
                             ),
-                        )
+                        ),
                     ],
                 ),
                 state="replaced",
-            )
+            ),
         )
         self.execute_module(changed=False, commands=[])
 
@@ -317,7 +322,7 @@ class TestEosBgpglobalModule(TestEosModule):
                                 link_bandwidth_attribute="divide",
                                 divide="ratio",
                             ),
-                        )
+                        ),
                     ],
                     network=[
                         dict(address="6.6.6.0/24", route_map="netmap1"),
@@ -331,7 +336,7 @@ class TestEosBgpglobalModule(TestEosModule):
                     ],
                 ),
                 state="replaced",
-            )
+            ),
         )
         commands = [
             "router bgp 65535",
@@ -386,11 +391,11 @@ class TestEosBgpglobalModule(TestEosModule):
                                 dict(protocol="static"),
                                 dict(protocol="rip", route_map="MAP01"),
                             ],
-                        )
+                        ),
                     ],
                 ),
                 state="replaced",
-            )
+            ),
         )
         commands = [
             "router bgp 65535",
@@ -476,7 +481,7 @@ class TestEosBgpglobalModule(TestEosModule):
                                     maximum_received_routes=dict(count=12000),
                                 ),
                             ],
-                        )
+                        ),
                     ],
                     default_metric=433,
                     network=[
@@ -487,11 +492,12 @@ class TestEosBgpglobalModule(TestEosModule):
                     route_target=dict(action="export", target="44:22"),
                 ),
                 state="merged",
-            )
+            ),
         )
         result = self.execute_module(failed=True)
         self.assertIn(
-            "Only one bgp instance is allowed per device", result["msg"]
+            "Only one bgp instance is allowed per device",
+            result["msg"],
         )
 
     def test_eos_bgp_global_replaced_with_af(self):
@@ -508,10 +514,11 @@ class TestEosBgpglobalModule(TestEosModule):
                     route_target=dict(action="export", target="44:22"),
                 ),
                 state="replaced",
-            )
+            ),
         )
         result = self.execute_module(
-            failed=True, filename="eos_bgp_global_af_config.cfg"
+            failed=True,
+            filename="eos_bgp_global_af_config.cfg",
         )
         self.assertIn(
             "Use the _bgp_address_family module to delete the address_family under vrf, before replacing/deleting the vrf.",
@@ -521,7 +528,8 @@ class TestEosBgpglobalModule(TestEosModule):
     def test_eos_bgp_global_deleted_with_af(self):
         set_module_args(dict(config=dict(as_number="65535"), state="deleted"))
         result = self.execute_module(
-            failed=True, filename="eos_bgp_global_af_config.cfg"
+            failed=True,
+            filename="eos_bgp_global_af_config.cfg",
         )
         self.assertIn(
             "Use the _bgp_address_family module to delete the address_family under vrf, before replacing/deleting the vrf.",
@@ -531,7 +539,8 @@ class TestEosBgpglobalModule(TestEosModule):
     def test_eos_bgp_global_gathered(self):
         set_module_args(dict(state="gathered"))
         result = self.execute_module(
-            changed=False, filename="eos_bgp_global_config.cfg"
+            changed=False,
+            filename="eos_bgp_global_config.cfg",
         )
         gather_list = {
             "aggregate_address": [
@@ -580,7 +589,7 @@ class TestEosBgpglobalModule(TestEosModule):
                         {"address": "10.1.0.0/16"},
                     ],
                     "redistribute": [
-                        {"isis_level": "level-2", "protocol": "isis"}
+                        {"isis_level": "level-2", "protocol": "isis"},
                     ],
                     "route_target": {
                         "action": "export",
@@ -588,7 +597,7 @@ class TestEosBgpglobalModule(TestEosModule):
                         "imported_route": True,
                     },
                     "vrf": "vrf01",
-                }
+                },
             ],
         }
         self.assertEqual(sorted(gather_list), sorted(result["gathered"]))
@@ -624,7 +633,8 @@ class TestEosBgpglobalModule(TestEosModule):
         parsed_str = "\n".join(commands)
         set_module_args(dict(running_config=parsed_str, state="parsed"))
         result = self.execute_module(
-            changed=False, filename="eos_bgp_global_config.cfg"
+            changed=False,
+            filename="eos_bgp_global_config.cfg",
         )
         parsed_list = {
             "aggregate_address": [
@@ -670,7 +680,7 @@ class TestEosBgpglobalModule(TestEosModule):
                         {"address": "10.1.0.0/16"},
                     ],
                     "redistribute": [
-                        {"isis_level": "level-2", "protocol": "isis"}
+                        {"isis_level": "level-2", "protocol": "isis"},
                     ],
                     "route_target": {
                         "action": "export",
@@ -678,7 +688,7 @@ class TestEosBgpglobalModule(TestEosModule):
                         "target": "44:22",
                     },
                     "vrf": "vrf01",
-                }
+                },
             ],
         }
         self.assertEqual(sorted(parsed_list), sorted(result["parsed"]))
@@ -708,7 +718,8 @@ class TestEosBgpglobalModule(TestEosModule):
                                     peer="peer2",
                                     peer_group="peer2",
                                     encryption_password=dict(
-                                        password="mypassword", type=0
+                                        password="mypassword",
+                                        type=0,
                                     ),
                                     ebgp_multihop=dict(ttl=10),
                                     enforce_first_as=True,
@@ -718,7 +729,8 @@ class TestEosBgpglobalModule(TestEosModule):
                                     link_bandwidth=dict(auto=True),
                                     local_as=dict(as_number=55, fallback=True),
                                     maximum_accepted_routes=dict(
-                                        count=6, warning_limit=4
+                                        count=6,
+                                        warning_limit=4,
                                     ),
                                     maximum_received_routes=dict(
                                         count=6,
@@ -734,16 +746,18 @@ class TestEosBgpglobalModule(TestEosModule):
                                     remote_as=55,
                                     remove_private_as=dict(replace_as=True),
                                     prefix_list=dict(
-                                        name="list01", direction="in"
+                                        name="list01",
+                                        direction="in",
                                     ),
                                     route_map=dict(
-                                        name="map01", direction="out"
+                                        name="map01",
+                                        direction="out",
                                     ),
                                     route_reflector_client=True,
                                     route_to_peer=True,
                                 ),
                             ],
-                        )
+                        ),
                     ],
                     default_metric=433,
                     network=[
@@ -771,11 +785,11 @@ class TestEosBgpglobalModule(TestEosModule):
                         host_routes=True,
                     ),
                     access_group=[
-                        dict(afi="ipv6", acl_name="acl01", direction="out")
+                        dict(afi="ipv6", acl_name="acl01", direction="out"),
                     ],
                 ),
                 state="rendered",
-            )
+            ),
         )
         rendered_cmds = [
             "router bgp 65535",
