@@ -25,10 +25,12 @@ options:
         description:
             - Name of the resource group containing the virtual machine scale set.
         required: true
+        type: str
     name:
         description:
             - Name of the virtual machine.
         required: true
+        type: str
     state:
         description:
             - Assert the state of the virtual machine scale set.
@@ -36,26 +38,32 @@ options:
               of the existing machine does not match, the machine will be updated.
             - State C(absent) will remove the virtual machine scale set.
         default: present
+        type: str
         choices:
             - absent
             - present
     location:
         description:
             - Valid Azure location. Defaults to location of the resource group.
+        type: str
     short_hostname:
         description:
             - Short host name.
+        type: str
     vm_size:
         description:
             - A valid Azure VM size value. For example, C(Standard_D4).
             - The list of choices varies depending on the subscription and location. Check your subscription for available choices.
+        type: str
     capacity:
         description:
             - Capacity of VMSS.
         default: 1
+        type: int
     tier:
         description:
             - SKU Tier.
+        type: str
         choices:
             - Basic
             - Standard
@@ -63,6 +71,7 @@ options:
         description:
             - Upgrade policy.
             - Required when creating the Azure virtual machine scale sets.
+        type: str
         choices:
             - Manual
             - Automatic
@@ -70,6 +79,7 @@ options:
         description:
             - Priority of the VMSS.
             - C(None) is the equivalent of Regular VM.
+        type: str
         choices:
             - None
             - Spot
@@ -77,6 +87,7 @@ options:
         description:
             - Specifies the eviction policy for the Azure Spot virtual machine.
             - Requires priority to be set to Spot.
+        type: str
         choices:
             - Deallocate
             - Delete
@@ -87,13 +98,16 @@ options:
             - C(-1) indicates default price to be up-to on-demand.
             - Requires priority to be set to Spot.
         default: -1
+        type: float
     admin_username:
         description:
             - Admin username used to access the host after it is created. Required when creating a VM.
+        type: str
     admin_password:
         description:
             - Password for the admin username.
             - Not required if the os_type is Linux and SSH password authentication is disabled by setting I(ssh_password_enabled=false).
+        type: str
     ssh_password_enabled:
         description:
             - When the os_type is Linux, setting I(ssh_password_enabled=false) will disable SSH password authentication and require use of SSH keys.
@@ -106,6 +120,44 @@ options:
             - Set the C(path) to the default location of the authorized_keys files.
             - On an Enterprise Linux host, for example, the I(path=/home/<admin username>/.ssh/authorized_keys).
               Set C(key_data) to the actual value of the public key.
+        type: list
+        elements: dict
+    identity:
+        description:
+            - Identity for this resource.
+        type: dict
+        version_added: '2.5.0'
+        suboptions:
+            type:
+                description:
+                    - Type of the managed identity
+                choices:
+                    - SystemAssigned
+                    - UserAssigned
+                    - SystemAssigned, UserAssigned
+                    - 'None'
+                default: 'None'
+                type: str
+            user_assigned_identities:
+                description:
+                    - User Assigned Managed Identities and its options
+                required: false
+                type: dict
+                default: {}
+                suboptions:
+                    id:
+                        description:
+                            - List of the user assigned IDs associated to this resource
+                        required: false
+                        type: list
+                        elements: str
+                        default: []
+                    append:
+                        description:
+                            - If the list of identities has to be appended to current identities (true) or if it has to replace current identities (false)
+                        required: false
+                        type: bool
+                        default: True
     image:
         description:
             - Specifies the image used to build the VM.
@@ -115,10 +167,12 @@ options:
             - If a dict with the keys I(name) and I(resource_group), the image is sourced from a custom image based on the I(name) and I(resource_group) set.
               Note that the key I(resource_group) is optional and if omitted, all images in the subscription will be searched for by I(name).
             - Custom image support was added in Ansible 2.5.
-        required: true
+            - Required when creating.
+        type: raw
     os_disk_caching:
         description:
             - Type of OS disk caching.
+        type: str
         choices:
             - ReadOnly
             - ReadWrite
@@ -133,6 +187,7 @@ options:
     os_type:
         description:
             - Base type of operating system.
+        type: str
         choices:
             - Windows
             - Linux
@@ -145,29 +200,44 @@ options:
     managed_disk_type:
         description:
             - Managed disk type.
+        type: str
         choices:
             - Standard_LRS
             - Premium_LRS
+            - StandardSSD_LRS
+            - UltraSSD_LRS
+            - Premium_ZRS
+            - StandardSSD_ZRS
     data_disks:
         description:
             - Describes list of data disks.
+        type: list
+        elements: dict
         suboptions:
             lun:
                 description:
                     - The logical unit number for data disk.
-                default: 0
+                default: '0'
+                type: str
             disk_size_gb:
                 description:
                     - The initial disk size in GB for blank data disks.
+                type: int
             managed_disk_type:
                 description:
                     - Managed data disk type.
+                type: str
                 choices:
                     - Standard_LRS
                     - Premium_LRS
+                    - StandardSSD_LRS
+                    - UltraSSD_LRS
+                    - Premium_ZRS
+                    - StandardSSD_ZRS
             caching:
                 description:
                     - Type of data disk caching.
+                type: str
                 choices:
                     - ReadOnly
                     - ReadWrite
@@ -177,14 +247,17 @@ options:
             - When creating a virtual machine, if a specific virtual network from another resource group should be
               used.
             - Use this parameter to specify the resource group to use.
+        type: str
     virtual_network_name:
         description:
             - Virtual Network name.
         aliases:
             - virtual_network
+        type: str
     subnet_name:
         description:
             - Subnet name.
+        type: str
         aliases:
             - subnet
     public_ip_per_vm:
@@ -195,14 +268,18 @@ options:
     load_balancer:
         description:
             - Load balancer name.
+        type: str
     application_gateway:
         description:
             - Application gateway name.
+        type: str
     remove_on_absent:
         description:
             - When removing a VM using I(state=absent), also remove associated resources.
             - It can be C(all) or a list with any of the following ['network_interfaces', 'virtual_storage', 'public_ips'].
             - Any other input will be ignored.
+        type: list
+        elements: str
         default: ['all']
     enable_accelerated_networking:
         description:
@@ -216,6 +293,7 @@ options:
             - It can be a dict which contains I(name) and I(resource_group) of the security group.
         aliases:
             - security_group_name
+        type: raw
     overprovision:
         description:
             - Specifies whether the Virtual Machine Scale Set should be overprovisioned.
@@ -234,21 +312,26 @@ options:
                 description:
                     - Billing plan name.
                 required: true
+                type: str
             product:
                 description:
                     - Product name.
                 required: true
+                type: str
             publisher:
                 description:
                     - Publisher offering the plan.
                 required: true
+                type: str
             promotion_code:
                 description:
                     - Optional promotion code.
+                type: str
     zones:
         description:
             - A list of Availability Zones for your virtual machine scale set.
         type: list
+        elements: str
     custom_data:
         description:
             - Data which is made available to the virtual machine and used by e.g., C(cloud-init).
@@ -256,9 +339,11 @@ options:
             - If the image you are attempting to use is not listed in
               U(https://docs.microsoft.com/en-us/azure/virtual-machines/linux/using-cloud-init#cloud-init-overview),
               follow these steps U(https://docs.microsoft.com/en-us/azure/virtual-machines/linux/cloudinit-prepare-custom-image).
+        type: str
     scale_in_policy:
         description:
             - define the order in which vmss instances are scaled-in
+        type: str
         choices:
             - Default
             - NewestVM
@@ -267,6 +352,7 @@ options:
         description:
             - timeout time for termination notification event
             - in range between 5 and 15
+        type: int
     platform_fault_domain_count:
         description:
             - Fault Domain count for each placement group.
@@ -284,6 +370,7 @@ options:
         choices:
             - Flexible
             - Uniform
+        default: Flexible
     security_profile:
         description:
             - Specifies the Security related profile settings for the virtual machine sclaset.
@@ -403,7 +490,7 @@ EXAMPLES = '''
     name: testvmss
     vm_size: Standard_DS1_v2
     capacity: 120
-    single_placement_group: False
+    single_placement_group: false
     virtual_network_name: testvnet
     upgrade_policy: Manual
     subnet_name: testsubnet
@@ -450,9 +537,9 @@ EXAMPLES = '''
     name: testVMSS{{ rpfx }}
     vm_size: Standard_D4s_v3
     admin_username: testuser
-    single_placement_group: False
+    single_placement_group: false
     platform_fault_domain_count: 1
-    public_ip_per_vm: True
+    public_ip_per_vm: true
     ssh_password_enabled: false
     ssh_public_keys:
       - path: /home/testuser/.ssh/authorized_keys
@@ -464,9 +551,9 @@ EXAMPLES = '''
     os_disk_caching: ReadWrite
     security_profile:
       uefi_settings:
-        secure_boot_enabled: True
-        v_tpm_enabled: False
-      encryption_at_host: False
+        secure_boot_enabled: true
+        v_tpm_enabled: false
+      encryption_at_host: false
       security_type: TrustedLaunch
     image:
       offer: 0001-com-ubuntu-server-jammy
@@ -596,18 +683,20 @@ azure_vmss:
 '''  # NOQA
 
 import base64
+import time
 
 try:
-    from msrestazure.azure_exceptions import CloudError
     from azure.core.exceptions import ResourceNotFoundError
-    from msrestazure.tools import parse_resource_id
+    from azure.mgmt.core.tools import parse_resource_id
     from azure.core.exceptions import ResourceNotFoundError
+    from azure.mgmt.compute.models import (VirtualMachineScaleSetIdentity, UserAssignedIdentitiesValue)
 
 except ImportError:
     # This is handled in azure_rm_common
     pass
 
-from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase, azure_id_to_dict, format_resource_id
+from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import azure_id_to_dict, format_resource_id
+from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_ext import AzureRMModuleBaseExt
 from ansible.module_utils.basic import to_native, to_bytes
 
 
@@ -616,7 +705,37 @@ AZURE_OBJECT_CLASS = 'VirtualMachineScaleSet'
 AZURE_ENUM_MODULES = ['azure.mgmt.compute.models']
 
 
-class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
+user_assigned_identities_spec = dict(
+    id=dict(
+        type='list',
+        default=[],
+        elements='str'
+    ),
+    append=dict(
+        type='bool',
+        default=True
+    )
+)
+
+
+managed_identity_spec = dict(
+    type=dict(
+        type='str',
+        choices=['SystemAssigned',
+                 'UserAssigned',
+                 'SystemAssigned, UserAssigned',
+                 'None'],
+        default='None'
+    ),
+    user_assigned_identities=dict(
+        type='dict',
+        options=user_assigned_identities_spec,
+        default={}
+    ),
+)
+
+
+class AzureRMVirtualMachineScaleSet(AzureRMModuleBaseExt):
 
     def __init__(self):
 
@@ -636,25 +755,37 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
             admin_username=dict(type='str'),
             admin_password=dict(type='str', no_log=True),
             ssh_password_enabled=dict(type='bool', default=True),
-            ssh_public_keys=dict(type='list'),
+            ssh_public_keys=dict(type='list', elements='dict'),
             image=dict(type='raw'),
             os_disk_caching=dict(type='str', aliases=['disk_caching'], choices=['ReadOnly', 'ReadWrite'],
                                  default='ReadOnly'),
             os_type=dict(type='str', choices=['Linux', 'Windows'], default='Linux'),
-            managed_disk_type=dict(type='str', choices=['Standard_LRS', 'Premium_LRS']),
-            data_disks=dict(type='list'),
+            managed_disk_type=dict(type='str', choices=['Standard_LRS', 'Premium_LRS', 'StandardSSD_LRS', 'UltraSSD_LRS', 'Premium_ZRS', 'StandardSSD_ZRS']),
+            data_disks=dict(
+                type='list',
+                elements='dict',
+                options=dict(
+                    lun=dict(type='str', default='0'),
+                    disk_size_gb=dict(type='int'),
+                    caching=dict(type='str', default='ReadOnly', choices=['ReadOnly', 'ReadWrite']),
+                    managed_disk_type=dict(
+                        type='str',
+                        choices=['Standard_LRS', 'Premium_LRS', 'StandardSSD_LRS', 'UltraSSD_LRS', 'Premium_ZRS', 'StandardSSD_ZRS']
+                    )
+                )
+            ),
             subnet_name=dict(type='str', aliases=['subnet']),
             public_ip_per_vm=dict(type='bool', default=False),
             load_balancer=dict(type='str'),
             application_gateway=dict(type='str'),
             virtual_network_resource_group=dict(type='str'),
             virtual_network_name=dict(type='str', aliases=['virtual_network']),
-            remove_on_absent=dict(type='list', default=['all']),
+            remove_on_absent=dict(type='list', default=['all'], elements='str'),
             enable_accelerated_networking=dict(type='bool'),
             security_group=dict(type='raw', aliases=['security_group_name']),
             overprovision=dict(type='bool'),
             single_placement_group=dict(type='bool', default=False),
-            zones=dict(type='list'),
+            zones=dict(type='list', elements='str'),
             custom_data=dict(type='str'),
             plan=dict(type='dict', options=dict(publisher=dict(type='str', required=True),
                       product=dict(type='str', required=True), name=dict(type='str', required=True),
@@ -662,7 +793,9 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
             scale_in_policy=dict(type='str', choices=['Default', 'OldestVM', 'NewestVM']),
             terminate_event_timeout_minutes=dict(type='int'),
             ephemeral_os_disk=dict(type='bool'),
-            orchestration_mode=dict(type='str', choices=['Uniform', 'Flexible']),
+            orchestration_mode=dict(type='str',
+                                    choices=['Uniform', 'Flexible'],
+                                    default='Flexible',),
             platform_fault_domain_count=dict(type='int', default=1),
             os_disk_size_gb=dict(type='int'),
             security_profile=dict(
@@ -679,6 +812,10 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
                     )
                 )
             ),
+            identity=dict(
+                type='dict',
+                options=managed_identity_spec
+            ),
         )
 
         self.resource_group = None
@@ -721,6 +858,8 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
         self.orchestration_mode = None
         self.os_disk_size_gb = None
         self.security_profile = None
+        self._managed_identity = None
+        self.identity = None
 
         mutually_exclusive = [('load_balancer', 'application_gateway')]
         self.results = dict(
@@ -734,6 +873,14 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
             supports_check_mode=True,
             mutually_exclusive=mutually_exclusive)
 
+    @property
+    def managed_identity(self):
+        if not self._managed_identity:
+            self._managed_identity = {"identity": VirtualMachineScaleSetIdentity,
+                                      "user_assigned": UserAssignedIdentitiesValue
+                                      }
+        return self._managed_identity
+
     def exec_module(self, **kwargs):
 
         for key in list(self.module_arg_spec.keys()) + ['tags']:
@@ -854,18 +1001,18 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
             if self.state == 'present':
                 differences = []
                 results = vmss_dict
-                current_osdisk = vmss_dict['properties']['virtualMachineProfile']['storageProfile']['osDisk']
-                current_ephemeral = current_osdisk.get('diffDiskSettings', None)
-                current_properties = vmss_dict['properties']['virtualMachineProfile']
+                current_osdisk = vmss_dict['virtual_machine_profile']['storage_profile']['os_disk']
+                current_ephemeral = current_osdisk.get('diff_disk_settings', None)
+                current_properties = vmss_dict['virtual_machine_profile']
 
                 if self.priority and self.priority != current_properties.get('priority', 'None'):
                     self.fail('VM Priority is not updatable: requested virtual machine priority is {0}'.format(self.priority))
                 if self.eviction_policy and \
-                   self.eviction_policy != current_properties.get('evictionPolicy', None):
+                   self.eviction_policy != current_properties.get('eviction_policy', None):
                     self.fail('VM Eviction Policy is not updatable: requested virtual machine eviction policy is {0}'.format(self.eviction_policy))
                 if self.max_price and \
-                   vmss_dict['properties']['virtualMachineProfile'].get('billingProfile', None) and \
-                   self.max_price != vmss_dict['properties']['virtualMachineProfile']['billingProfile'].get('maxPrice', None):
+                   vmss_dict['virtual_machine_profile'].get('billing_profile', None) and \
+                   self.max_price != vmss_dict['virtual_machine_profile']['billing_profile'].get('max_price', None):
                     self.fail('VM Maximum Price is not updatable: requested virtual machine maximum price is {0}'.format(self.max_price))
 
                 if self.ephemeral_os_disk and current_ephemeral is None:
@@ -874,15 +1021,15 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
                     self.fail('Ephemeral OS disk not updatable: virtual machine scale set ephemeral OS disk is {0}'.format(self.ephemeral_os_disk))
 
                 if self.os_disk_size_gb and \
-                   self.os_disk_size_gb != vmss_dict['properties']['virtualMachineProfile']['storageProfile']['osDisk']['diskSizeGB']:
+                   self.os_disk_size_gb != vmss_dict['virtual_machine_profile']['storage_profile']['os_disk']['disk_size_gb']:
                     self.fail('VMSS OS disk size is not updatable: requested virtual machine OS disk size is {0}'.format(self.os_disk_size_gb))
 
                 if self.os_disk_caching and \
-                   self.os_disk_caching != vmss_dict['properties']['virtualMachineProfile']['storageProfile']['osDisk']['caching']:
+                   self.os_disk_caching != vmss_dict['virtual_machine_profile']['storage_profile']['os_disk']['caching']:
                     self.log('CHANGED: virtual machine scale set {0} - OS disk caching'.format(self.name))
                     differences.append('OS Disk caching')
                     changed = True
-                    vmss_dict['properties']['virtualMachineProfile']['storageProfile']['osDisk']['caching'] = self.os_disk_caching
+                    vmss_dict['virtual_machine_profile']['storage_profile']['os_disk']['caching'] = self.os_disk_caching
 
                 if self.capacity and \
                    self.capacity != vmss_dict['sku']['capacity']:
@@ -892,35 +1039,41 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
                     vmss_dict['sku']['capacity'] = self.capacity
 
                 if self.data_disks and \
-                   len(self.data_disks) != len(vmss_dict['properties']['virtualMachineProfile']['storageProfile'].get('dataDisks', [])):
+                   len(self.data_disks) != len(vmss_dict['virtual_machine_profile']['storage_profile'].get('data_disks', [])):
                     self.log('CHANGED: virtual machine scale set {0} - Data Disks'.format(self.name))
                     differences.append('Data Disks')
                     changed = True
 
                 if self.upgrade_policy and \
-                   self.upgrade_policy != vmss_dict['properties']['upgradePolicy']['mode']:
+                   self.upgrade_policy != vmss_dict['upgrade_policy']['mode']:
                     self.log('CHANGED: virtual machine scale set {0} - Upgrade Policy'.format(self.name))
                     differences.append('Upgrade Policy')
                     changed = True
-                    vmss_dict['properties']['upgradePolicy']['mode'] = self.upgrade_policy
+                    vmss_dict['upgrade_policy']['mode'] = self.upgrade_policy
 
                 if image_reference and \
-                   image_reference.as_dict() != vmss_dict['properties']['virtualMachineProfile']['storageProfile']['imageReference']:
+                   image_reference.as_dict() != vmss_dict['virtual_machine_profile']['storage_profile']['image_reference']:
                     self.log('CHANGED: virtual machine scale set {0} - Image'.format(self.name))
                     differences.append('Image')
                     changed = True
-                    vmss_dict['properties']['virtualMachineProfile']['storageProfile']['imageReference'] = image_reference.as_dict()
+                    vmss_dict['virtual_machine_profile']['storage_profile']['image_reference'] = image_reference.as_dict()
+
+                if self.identity:
+                    update_identity, self.identity = self.update_identities(vmss_dict.get('identity', dict()))
+                    if update_identity:
+                        differences.append('Identity')
+                        changed = True
 
                 update_tags, vmss_dict['tags'] = self.update_tags(vmss_dict.get('tags', dict()))
                 if update_tags:
                     differences.append('Tags')
                     changed = True
 
-                if self.overprovision is not None and bool(self.overprovision) != bool(vmss_dict['properties'].get('overprovision')):
+                if self.overprovision is not None and bool(self.overprovision) != bool(vmss_dict.get('overprovision')):
                     differences.append('overprovision')
                     changed = True
 
-                if bool(self.single_placement_group) != bool(vmss_dict['properties']['singlePlacementGroup']):
+                if bool(self.single_placement_group) != bool(vmss_dict['single_placement_group']):
                     differences.append('single_placement_group')
                     changed = True
 
@@ -936,26 +1089,26 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
                     if timeout < 5 or timeout > 15:
                         self.fail("terminate_event_timeout_minutes should >= 5 and <= 15")
                     iso_8601_format = "PT" + str(timeout) + "M"
-                    old = vmss_dict['properties']['virtualMachineProfile'].get('scheduledEventsProfile', {}).\
-                        get('terminateNotificationProfile', {}).get('notBeforeTimeout', "")
+                    old = vmss_dict['virtual_machine_profile'].get('scheduled_events_profile', {}).\
+                        get('terminate_notification_profile', {}).get('not_before_timeout', "")
                     if old != iso_8601_format:
                         differences.append('terminateNotification')
                         changed = True
-                        vmss_dict['properties']['virtualMachineProfile'].setdefault('scheduledEventsProfile', {})['terminateNotificationProfile'] = {
-                            'notBeforeTimeout': iso_8601_format,
+                        vmss_dict['virtual_machine_profile'].setdefault('scheduled_events_profile', {})['terminate_notification_profile'] = {
+                            'not_before_timeout': iso_8601_format,
                             "enable": 'true'
                         }
 
-                if self.scale_in_policy and self.scale_in_policy != vmss_dict['properties'].get('scaleInPolicy', {}).get('rules', [""])[0]:
+                if self.scale_in_policy and self.scale_in_policy != vmss_dict.get('scale_in_policy', {}).get('rules', [""])[0]:
                     self.log("CHANGED: virtual machine sale sets {0} scale in policy".format(self.name))
                     differences.append('scaleInPolicy')
                     changed = True
-                    vmss_dict['properties'].setdefault('scaleInPolicy', {})['rules'] = [self.scale_in_policy]
+                    vmss_dict.setdefault('scale_in_policy', {})['rules'] = [self.scale_in_policy]
 
-                nicConfigs = vmss_dict['properties']['virtualMachineProfile']['networkProfile']['networkInterfaceConfigurations']
+                nicConfigs = vmss_dict['virtual_machine_profile']['network_profile']['network_interface_configurations']
 
-                backend_address_pool = nicConfigs[0]['properties']['ipConfigurations'][0]['properties'].get('loadBalancerBackendAddressPools', [])
-                backend_address_pool += nicConfigs[0]['properties']['ipConfigurations'][0]['properties'].get('applicationGatewayBackendAddressPools', [])
+                backend_address_pool = nicConfigs[0]['ip_configurations'][0].get('load_balancer_backend_address_pools', [])
+                backend_address_pool += nicConfigs[0]['ip_configurations'][0].get('application_gateway_backend_address_pools', [])
                 lb_or_ag_id = None
                 if (len(nicConfigs) != 1 or len(backend_address_pool) != 1):
                     support_lb_change = False  # Currently not support for the vmss contains more than one loadbalancer
@@ -972,51 +1125,51 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
                         changed = True
 
                 if self.custom_data:
-                    if self.custom_data != vmss_dict['properties']['virtualMachineProfile']['osProfile'].get('customData'):
+                    if self.custom_data != vmss_dict['virtual_machine_profile']['os_profile'].get('custom_data'):
                         differences.append('custom_data')
                         changed = True
-                        vmss_dict['properties']['virtualMachineProfile']['osProfile']['customData'] = self.custom_data
+                        vmss_dict['virtual_machine_profile']['os_profile']['custom_data'] = self.custom_data
 
-                if self.orchestration_mode and self.orchestration_mode != vmss_dict['properties'].get('orchestrationMode'):
+                if self.orchestration_mode and self.orchestration_mode != vmss_dict.get('orchestration_mode'):
                     self.fail("The orchestration_mode parameter cannot be updated!")
                 else:
-                    self.orchestration_mode = vmss_dict['properties'].get('orchestrationMode')
+                    self.orchestration_mode = vmss_dict.get('orchestration_mode')
 
-                if self.platform_fault_domain_count and self.platform_fault_domain_count != vmss_dict['properties'].get('platformFaultDomainCount'):
+                if self.platform_fault_domain_count and self.platform_fault_domain_count != vmss_dict.get('platform_fault_domain_count'):
                     self.fail("The platform_fault_domain_count parameter cannot be updated!")
 
                 if self.security_profile is not None:
                     update_security_profile = False
-                    if 'securityProfile' not in vmss_dict['properties']['virtualMachineProfile'].keys():
+                    if 'securityProfile' not in vmss_dict['virtual_machine_profile'].keys():
                         update_security_profile = True
                         differences.append('security_profile')
                     else:
                         if self.security_profile.get('encryption_at_host') is not None:
                             if bool(self.security_profile.get('encryption_at_host')) != \
-                                    bool(vmss_dict['properties']['virtualMachineProfile']['securityProfile']['encryptionAtHost']):
+                                    bool(vmss_dict['virtual_machine_profile']['security_profile']['encryption_at_host']):
                                 update_security_profle = True
                             else:
                                 self.security_profile['encryption_at_host'] = \
-                                    vmss_dict['properties']['virtualMachineProfile']['securityProfile']['encryptionAtHost']
+                                    vmss_dict['virtual_machine_profile']['security_profile']['encryption_at_host']
                         if self.security_profile.get('security_type') is not None:
                             if self.security_profile.get('security_type') != \
-                                    vmss_dict['properties']['virtualMachineProfile']['securityProfile']['securityType']:
+                                    vmss_dict['virtual_machine_profile']['security_profile']['security_type']:
                                 update_security_profile = True
                         if self.security_profile.get('uefi_settings') is not None:
                             if self.security_profile['uefi_settings'].get('secure_boot_enabled') is not None:
                                 if bool(self.security_profile['uefi_settings']['secure_boot_enabled']) != \
-                                        bool(vmss_dict['properties']['virtualMachineProfile']['securityProfile']['uefiSettings']['secureBootEnabled']):
+                                        bool(vmss_dict['virtual_machine_profile']['security_profile']['uefi_settings']['secure_boot_nabled']):
                                     update_security_profile = True
                             else:
                                 self.security_profile['uefi_settings']['secure_boot_enabled'] = \
-                                    vmss_dict['properties']['virtualMachineProfile']['securityProfile']['uefiSettings']['secureBootEnabled']
+                                    vmss_dict['virtual_machine_profile']['security_profile']['uefi_settings']['secure_boot_enabled']
                             if self.security_profile['uefi_settings'].get('v_tpm_enabled') is not None:
                                 if bool(self.security_profile['uefi_settings']['v_tpm_enabled']) != \
-                                        bool(vmss_dict['properties']['virtualMachineProfile']['securityProfile']['uefiSettings']['vTpmEnabled']):
+                                        bool(vmss_dict['virtual_machine_profile']['security_profile']['uefi_settings']['v_tpm_enabled']):
                                     update_security_profile = True
                             else:
                                 self.security_profile['uefi_settings']['v_tpm_enabled'] = \
-                                    vmss_dict['properties']['virtualMachineProfile']['securityProfile']['uefiSettings']['vTpmEnabled']
+                                    vmss_dict['virtual_machine_profile']['security_profile']['uefi_settings']['v_tpm_enabled']
                         if update_security_profile:
                             changed = True
                             differences.append('security_profile')
@@ -1033,6 +1186,8 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
             if self.state == 'present':
                 self.log("CHANGED: virtual machine scale set {0} does not exist but state is 'present'.".format(self.name))
                 changed = True
+                if self.identity:
+                    update_identity, self.identity = self.update_identities(dict())
 
         self.results['changed'] = changed
         self.results['ansible_facts']['azure_vmss'] = results
@@ -1144,6 +1299,9 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
                         zones=self.zones
                     )
 
+                    if self.identity:
+                        vmss_resource.identity = self.identity
+
                     if self.priority == 'Spot':
                         vmss_resource.virtual_machine_profile.priority = self.priority
                         vmss_resource.virtual_machine_profile.eviction_policy = self.eviction_policy
@@ -1200,10 +1358,10 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
                             plan_product = self.plan.get('product')
                             plan_publisher = self.plan.get('publisher')
                             term = self.marketplace_client.marketplace_agreements.get(
-                                publisher_id=plan_publisher, offer_id=plan_product, plan_id=plan_name)
+                                offer_type='virtualmachine', publisher_id=plan_publisher, offer_id=plan_product, plan_id=plan_name)
                             term.accepted = True
                             self.marketplace_client.marketplace_agreements.create(
-                                publisher_id=plan_publisher, offer_id=plan_product, plan_id=plan_name, parameters=term)
+                                offer_type='virtualmachine', publisher_id=plan_publisher, offer_id=plan_product, plan_id=plan_name, parameters=term)
                         except Exception as exc:
                             self.fail(("Error accepting terms for virtual machine {0} with plan {1}. " +
                                        "Only service admin/account admin users can purchase images " +
@@ -1288,6 +1446,9 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
                     if self.terminate_event_timeout_minutes:
                         vmss_resource.virtual_machine_profile.scheduled_events_profile = self.gen_scheduled_event_profile()
 
+                    if self.identity:
+                        vmss_resource.identity = self.identity
+
                     if image_reference is not None:
                         vmss_resource.virtual_machine_profile.storage_profile.image_reference = image_reference
 
@@ -1314,7 +1475,18 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
         :return: VirtualMachineScaleSet object
         '''
         try:
+            retry_count = 0
             vmss = self.compute_client.virtual_machine_scale_sets.get(self.resource_group, self.name)
+            while True:
+                if retry_count == 20:
+                    self.fail("Error {0} has a provisioning state of Updating. Expecting state to be Successed.".format(self.name))
+
+                if vmss.provisioning_state != 'Succeeded':
+                    retry_count = retry_count + 1
+                    time.sleep(150)
+                    vmss = self.compute_client.virtual_machine_scale_sets.get(self.resource_group, self.name)
+                else:
+                    break
             return vmss
         except ResourceNotFoundError as exc:
             self.fail("Error getting virtual machine scale set {0} - {1}".format(self.name, str(exc)))
@@ -1330,7 +1502,7 @@ class AzureRMVirtualMachineScaleSet(AzureRMModuleBase):
         self.log("Fetching subnet {0} in virtual network {1}".format(subnet_name, vnet_name))
         try:
             subnet = self.network_client.subnets.get(self.virtual_network_resource_group, vnet_name, subnet_name)
-        except CloudError as exc:
+        except Exception as exc:
             self.fail("Error: fetching subnet {0} in virtual network {1} - {2}".format(
                 subnet_name,
                 vnet_name,
