@@ -497,12 +497,10 @@ options:
     suboptions:
       rollbackTemplateErrors:
         description: Validation or design conflicts errors of rollback template.
-        elements: dict
-        type: list
+        type: dict
       templateErrors:
         description: Validation or design conflicts errors.
-        elements: dict
-        type: list
+        type: dict
       templateId:
         description: UUID of template.
         type: str
@@ -514,8 +512,15 @@ options:
     description: Current version of template.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
+- dnacentersdk >= 2.7.1
 - python >= 3.5
+seealso:
+- name: Cisco DNA Center documentation for Configuration Templates DeletesTheTemplate
+  description: Complete reference of the DeletesTheTemplate API.
+  link: https://developer.cisco.com/docs/dna-center/#!deletes-the-template
+- name: Cisco DNA Center documentation for Configuration Templates UpdateTemplate
+  description: Complete reference of the UpdateTemplate API.
+  link: https://developer.cisco.com/docs/dna-center/#!update-template
 notes:
   - SDK Method used are
     configuration_templates.ConfigurationTemplates.deletes_the_template,
@@ -689,10 +694,8 @@ EXAMPLES = r"""
         selectionType: string
         selectionValues: {}
     validationErrors:
-      rollbackTemplateErrors:
-      - {}
-      templateErrors:
-      - {}
+      rollbackTemplateErrors: {}
+      templateErrors: {}
       templateId: string
       templateVersion: string
     version: string
@@ -710,7 +713,6 @@ EXAMPLES = r"""
     templateId: string
 
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
