@@ -10,7 +10,7 @@ module: site_count_info
 short_description: Information module for Site Count
 description:
 - Get all Site Count.
-- API to get site count.
+- Get the site count of the specified site's sub-hierarchy inclusive of the provided site .
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,11 +21,15 @@ options:
     type: dict
   siteId:
     description:
-    - SiteId query parameter. Site id to retrieve site count.
+    - SiteId query parameter. Site instance UUID.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
+- dnacentersdk >= 2.7.1
 - python >= 3.5
+seealso:
+- name: Cisco DNA Center documentation for Sites GetSiteCount
+  description: Complete reference of the GetSiteCount API.
+  link: https://developer.cisco.com/docs/dna-center/#!get-site-count
 notes:
   - SDK Method used are
     sites.Sites.get_site_count,
@@ -45,13 +49,11 @@ EXAMPLES = r"""
     dnac_port: "{{dnac_port}}"
     dnac_version: "{{dnac_version}}"
     dnac_debug: "{{dnac_debug}}"
-    headers:
-      custom: value
+    headers: "{{my_headers | from_json}}"
     siteId: string
   register: result
 
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
