@@ -7,11 +7,10 @@ from __future__ import absolute_import, division, print_function
 
 
 __metaclass__ = type
-
 from textwrap import dedent
+from unittest.mock import patch
 
 from ansible_collections.cisco.ios.plugins.modules import ios_bgp_global
-from ansible_collections.cisco.ios.tests.unit.compat.mock import patch
 from ansible_collections.cisco.ios.tests.unit.modules.utils import AnsibleFailJson, set_module_args
 
 from .ios_module import TestIosModule
@@ -23,33 +22,12 @@ class TestIosBgpGlobalModule(TestIosModule):
     def setUp(self):
         super(TestIosBgpGlobalModule, self).setUp()
 
-        self.mock_get_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.get_config",
-        )
-        self.get_config = self.mock_get_config.start()
-
-        self.mock_load_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.load_config",
-        )
-        self.load_config = self.mock_load_config.start()
-
-        self.mock_get_resource_connection_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.cfg.base."
-            "get_resource_connection",
-        )
-        self.get_resource_connection_config = self.mock_get_resource_connection_config.start()
-
         self.mock_get_resource_connection_facts = patch(
             "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.resource_module_base."
             "get_resource_connection",
         )
         self.get_resource_connection_facts = self.mock_get_resource_connection_facts.start()
 
-        self.mock_edit_config = patch(
-            "ansible_collections.cisco.ios.plugins.module_utils.network.ios.providers.providers.CliProvider.edit_config",
-        )
-        self.edit_config = self.mock_edit_config.start()
-
         self.mock_execute_show_command = patch(
             "ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.bgp_global.bgp_global."
             "Bgp_globalFacts.get_bgp_global_data",
@@ -58,11 +36,7 @@ class TestIosBgpGlobalModule(TestIosModule):
 
     def tearDown(self):
         super(TestIosBgpGlobalModule, self).tearDown()
-        self.mock_get_resource_connection_config.stop()
         self.mock_get_resource_connection_facts.stop()
-        self.mock_edit_config.stop()
-        self.mock_get_config.stop()
-        self.mock_load_config.stop()
         self.mock_execute_show_command.stop()
 
     def test_ios_bgp_global_merged(self):
@@ -92,8 +66,16 @@ class TestIosBgpGlobalModule(TestIosModule):
                             "netmask": "255.255.0.0",
                             "summary_only": True,
                         },
-                        {"address": "192.0.2.4", "as_set": True, "netmask": "255.255.255.0"},
-                        {"address": "192.0.2.5", "as_set": True, "netmask": "255.255.255.0"},
+                        {
+                            "address": "192.0.2.4",
+                            "as_set": True,
+                            "netmask": "255.255.255.0",
+                        },
+                        {
+                            "address": "192.0.2.5",
+                            "as_set": True,
+                            "netmask": "255.255.255.0",
+                        },
                     ],
                     "as_number": "65000",
                     "auto_summary": True,
@@ -108,7 +90,9 @@ class TestIosBgpGlobalModule(TestIosModule):
                             "med": {"confed": True, "missing_as_worst": True},
                         },
                         "confederation": {"identifier": "22"},
-                        "consistency_checker": {"error_message": {"interval": 10, "set": True}},
+                        "consistency_checker": {
+                            "error_message": {"interval": 10, "set": True},
+                        },
                         "dampening": {
                             "max_suppress": 44,
                             "penalty_half_time": 22,
@@ -123,12 +107,23 @@ class TestIosBgpGlobalModule(TestIosModule):
                             "neighbors": {"time": 31},
                         },
                         "inject_maps": [
-                            {"copy_attributes": True, "exist_map_name": "mp2", "name": "map1"},
-                            {"copy_attributes": True, "exist_map_name": "mp3", "name": "map2"},
+                            {
+                                "copy_attributes": True,
+                                "exist_map_name": "mp2",
+                                "name": "map1",
+                            },
+                            {
+                                "copy_attributes": True,
+                                "exist_map_name": "mp3",
+                                "name": "map2",
+                            },
                         ],
                         "listen": {
                             "limit": 200,
-                            "range": {"host_with_subnet": "192.0.2.9/24", "peer_group": "mygrp"},
+                            "range": {
+                                "host_with_subnet": "192.0.2.9/24",
+                                "peer_group": "mygrp",
+                            },
                         },
                         "log_neighbor_changes": True,
                         "maxas_limit": 2,
@@ -157,8 +152,16 @@ class TestIosBgpGlobalModule(TestIosModule):
                     },
                     "bmp": {"buffer_size": 22},
                     "distance": {
-                        "bgp": {"routes_external": 2, "routes_internal": 3, "routes_local": 4},
-                        "mbgp": {"routes_external": 2, "routes_internal": 3, "routes_local": 5},
+                        "bgp": {
+                            "routes_external": 2,
+                            "routes_internal": 3,
+                            "routes_local": 4,
+                        },
+                        "mbgp": {
+                            "routes_external": 2,
+                            "routes_internal": 3,
+                            "routes_local": 5,
+                        },
                     },
                     "distributes": [
                         {"out": True, "prefix": "workcheck"},
@@ -166,8 +169,16 @@ class TestIosBgpGlobalModule(TestIosModule):
                     ],
                     "maximum_paths": {"ibgp": 22},
                     "maximum_secondary_paths": {"ibgp": 22, "paths": 12},
+                    "template": {"peer_policy": "Test1"},
                     "neighbors": [
-                        {"neighbor_address": "192.0.2.3", "remote_as": "300"},
+                        {
+                            "neighbor_address": "192.0.2.3",
+                            "remote_as": "300",
+                            "timers": {
+                                "holdtime": 20,
+                                "interval": 10,
+                            },
+                        },
                         {
                             "aigp": {
                                 "send": {
@@ -183,7 +194,13 @@ class TestIosBgpGlobalModule(TestIosModule):
                     ],
                     "redistribute": [
                         {"application": {"metric": 22, "name": "ap1"}},
-                        {"application": {"metric": 33, "name": "ap112", "route_map": "mp1"}},
+                        {
+                            "application": {
+                                "metric": 33,
+                                "name": "ap112",
+                                "route_map": "mp1",
+                            },
+                        },
                         {"connected": {"metric": 22}},
                         {"static": {"metric": 33, "route_map": "mp1"}},
                         {"mobile": {"metric": 211}},
@@ -248,11 +265,13 @@ class TestIosBgpGlobalModule(TestIosModule):
             "neighbor 192.0.2.4 remote-as 100.1",
             "neighbor 192.0.2.4 aigp send cost-community 100 poi igp-cost transitive",
             "neighbor 192.0.2.3 remote-as 300",
+            "neighbor 192.0.2.3 timers 10 20",
             "redistribute connected metric 22",
-            "redistribute application ap112 metric 33 route-map mp1",
-            "redistribute application ap1 metric 22",
+            "template peer-policy Test1",
             "redistribute mobile metric 211",
+            "redistribute application ap1 metric 22",
             "redistribute static metric 33 route-map mp1",
+            "redistribute application ap112 metric 33 route-map mp1",
         ]
         result = self.execute_module(changed=True)
         self.assertEqual(sorted(result["commands"]), sorted(commands))
@@ -335,7 +354,6 @@ class TestIosBgpGlobalModule(TestIosModule):
                 state="merged",
             ),
         )
-        # self.assertEqual(sorted(result["commands"]), sorted(commands))
         with self.assertRaises(AnsibleFailJson) as error:
             self.execute_module(changed=False, commands=[])
         self.assertIn(
@@ -343,6 +361,78 @@ class TestIosBgpGlobalModule(TestIosModule):
             str(error.exception),
         )
 
+    def test_ios_bgp_global_overridden(self):
+        self.execute_show_command.return_value = dedent(
+            """\
+            router bgp 65000
+             bgp nopeerup-delay post-boot 10
+             bgp bestpath compare-routerid
+             bgp advertise-best-external
+             aggregate-address 192.168.0.11 255.255.0.0 attribute-map map1
+             timers bgp 100 200 150
+             redistribute connected metric 10
+             neighbor 192.0.2.2 remote-as 100
+             neighbor 192.0.2.2 route-map test-route out
+             address-family ipv4
+              neighbor 192.0.2.28 activate
+              neighbor 172.31.35.140 activate
+            """,
+        )
+        set_module_args(
+            dict(
+                config=dict(
+                    as_number="65000",
+                    aggregate_address=dict(
+                        dict(
+                            address="192.168.0.11",
+                            attribute_map="map1",
+                            netmask="255.255.0.0",
+                        ),
+                    ),
+                    aggregate_addresses=[
+                        dict(
+                            address="192.168.0.1",
+                            attribute_map="map",
+                            netmask="255.255.0.0",
+                        ),
+                        dict(
+                            address="192.168.0.2",
+                            attribute_map="map2",
+                            netmask="255.255.0.0",
+                        ),
+                    ],
+                    bgp=dict(
+                        advertise_best_external=True,
+                        bestpath_options=dict(compare_routerid=True),
+                        log_neighbor_changes=True,
+                        nopeerup_delay_options=dict(cold_boot=20, post_boot=10),
+                    ),
+                    redistribute=[dict(connected=dict(set=True, metric=10))],
+                    neighbors=[
+                        dict(
+                            address="192.0.2.1",
+                            remote_as=200,
+                            description="replace neighbor",
+                        ),
+                    ],
+                ),
+                state="overridden",
+            ),
+        )
+        commands = [
+            "router bgp 65000",
+            "no timers bgp 100 200 150",
+            "bgp log-neighbor-changes",
+            "bgp nopeerup-delay cold-boot 20",
+            "aggregate-address 192.168.0.1 255.255.0.0 attribute-map map",
+            "aggregate-address 192.168.0.2 255.255.0.0 attribute-map map2",
+            "neighbor 192.0.2.1 remote-as 200",
+            "neighbor 192.0.2.1 description replace neighbor",
+            "no neighbor 192.0.2.2",
+        ]
+        result = self.execute_module(changed=True)
+        self.assertEqual(sorted(result["commands"]), sorted(commands))
+
     def test_ios_bgp_global_replaced(self):
         self.execute_show_command.return_value = dedent(
             """\
@@ -365,21 +455,41 @@ class TestIosBgpGlobalModule(TestIosModule):
                 config=dict(
                     as_number="65000",
                     aggregate_address=dict(
-                        dict(address="192.168.0.11", attribute_map="map1", netmask="255.255.0.0"),
+                        dict(
+                            address="192.168.0.11",
+                            attribute_map="map1",
+                            netmask="255.255.0.0",
+                        ),
                     ),
                     aggregate_addresses=[
-                        dict(address="192.168.0.1", attribute_map="map", netmask="255.255.0.0"),
-                        dict(address="192.168.0.2", attribute_map="map2", netmask="255.255.0.0"),
+                        dict(
+                            address="192.168.0.1",
+                            attribute_map="map",
+                            netmask="255.255.0.0",
+                        ),
+                        dict(
+                            address="192.168.0.2",
+                            attribute_map="map2",
+                            netmask="255.255.0.0",
+                        ),
                     ],
                     bgp=dict(
                         advertise_best_external=True,
                         bestpath_options=dict(compare_routerid=True),
+                        default=dict(
+                            ipv4_unicast=False,
+                            route_target=dict(filter=True),
+                        ),
                         log_neighbor_changes=True,
                         nopeerup_delay_options=dict(cold_boot=20, post_boot=10),
                     ),
                     redistribute=[dict(connected=dict(set=True, metric=10))],
                     neighbors=[
-                        dict(address="192.0.2.1", remote_as=200, description="replace neighbor"),
+                        dict(
+                            address="192.0.2.1",
+                            remote_as=200,
+                            description="replace neighbor",
+                        ),
                     ],
                 ),
                 state="replaced",
@@ -387,6 +497,7 @@ class TestIosBgpGlobalModule(TestIosModule):
         )
         commands = [
             "router bgp 65000",
+            "no bgp default ipv4-unicast",
             "no timers bgp 100 200 150",
             "bgp log-neighbor-changes",
             "bgp nopeerup-delay cold-boot 20",
@@ -443,6 +554,7 @@ class TestIosBgpGlobalModule(TestIosModule):
         self.execute_show_command.return_value = dedent(
             """\
             router bgp 65000
+             no bgp default ipv4-unicast
              bgp nopeerup-delay post-boot 10
              bgp bestpath compare-routerid
              bgp advertise-best-external
@@ -458,6 +570,7 @@ class TestIosBgpGlobalModule(TestIosModule):
         set_module_args(dict(config=dict(as_number=65000), state="deleted"))
         commands = [
             "router bgp 65000",
+            "bgp default ipv4-unicast",
             "no timers bgp 100 200 150",
             "no bgp advertise-best-external",
             "no bgp bestpath compare-routerid",
@@ -523,7 +636,10 @@ class TestIosBgpGlobalModule(TestIosModule):
                         },
                         "listen": {
                             "limit": 200,
-                            "range": {"ipv4_with_subnet": "192.0.2.9/24", "peer_group": "mygrp"},
+                            "range": {
+                                "ipv4_with_subnet": "192.0.2.9/24",
+                                "peer_group": "mygrp",
+                            },
                         },
                         "log_neighbor_changes": True,
                         "nopeerup_delay": [
@@ -537,10 +653,22 @@ class TestIosBgpGlobalModule(TestIosModule):
                     },
                     "bmp": {"buffer_size": 22, "server": 2},
                     "distance": {
-                        "bgp": {"routes_external": 2, "routes_internal": 3, "routes_local": 4},
-                        "mbgp": {"routes_external": 2, "routes_internal": 3, "routes_local": 5},
+                        "bgp": {
+                            "routes_external": 2,
+                            "routes_internal": 3,
+                            "routes_local": 4,
+                        },
+                        "mbgp": {
+                            "routes_external": 2,
+                            "routes_internal": 3,
+                            "routes_local": 5,
+                        },
+                    },
+                    "distribute_list": {
+                        "out": True,
+                        "acl": "5000",
+                        "interface": "Loopback0",
                     },
-                    "distribute_list": {"out": True, "acl": "5000", "interface": "Loopback0"},
                     "maximum_paths": {"ibgp": 2, "paths": 2},
                     "maximum_secondary_paths": {"ibgp": 22, "paths": 22},
                     "neighbors": [
@@ -575,7 +703,11 @@ class TestIosBgpGlobalModule(TestIosModule):
                             "send_community": {"extended": True},
                             "password": "new password",
                         },
-                        {"activate": True, "neighbor_address": "172.21.1.2", "remote_as": 45000},
+                        {
+                            "activate": True,
+                            "neighbor_address": "172.21.1.2",
+                            "remote_as": 45000,
+                        },
                         {"neighbor_address": "192.0.2.3", "remote_as": 300},
                         {
                             "neighbor_address": "192.0.2.4",
@@ -617,7 +749,13 @@ class TestIosBgpGlobalModule(TestIosModule):
                     "redistribute": [
                         {"static": {"metric": 33, "route_map": "mp1"}},
                         {"application": {"metric": 22, "name": "ap1"}},
-                        {"application": {"metric": 33, "name": "ap112", "route_map": "mp1"}},
+                        {
+                            "application": {
+                                "metric": 33,
+                                "name": "ap112",
+                                "route_map": "mp1",
+                            },
+                        },
                         {"connected": {"metric": 22}},
                         {"mobile": {"metric": 211}},
                     ],
@@ -713,6 +851,7 @@ class TestIosBgpGlobalModule(TestIosModule):
             "bgp": {
                 "nopeerup_delay_options": {"post_boot": 10},
                 "bestpath_options": {"compare_routerid": True},
+                "default": {"ipv4_unicast": True, "route_target": {"filter": True}},
                 "advertise_best_external": True,
             },
             "timers": {"keepalive": 100, "holdtime": 200, "min_holdtime": 150},
@@ -726,3 +865,136 @@ class TestIosBgpGlobalModule(TestIosModule):
             ],
         }
         self.assertEqual(parsed_list, result["parsed"])
+
+    def test_ios_bgp_global_action_states_specific_default(self):
+        self.execute_show_command.return_value = dedent(
+            """\
+            router bgp 6500
+             bgp log-neighbor-changes
+             no bgp default ipv4-unicast
+             no bgp default route-target filter
+             neighbor 192.0.2.1 remote-as 100
+             neighbor 192.0.2.1 description Test description
+             neighbor 192.0.2.2 remote-as 200
+             neighbor 192.0.2.2 description Test description 2
+             neighbor 192.0.2.2 shutdown
+             !
+             address-family ipv4
+             exit-address-family
+            """,
+        )
+        for stt in ["merged", "replaced", "overridden"]:
+            set_module_args(
+                {
+                    "config": {
+                        "as_number": "6500",
+                        "bgp": {
+                            "default": {
+                                "ipv4_unicast": False,
+                                "route_target": {
+                                    "filter": False,
+                                },
+                            },
+                            "log_neighbor_changes": True,
+                        },
+                        "neighbors": [
+                            {
+                                "neighbor_address": "192.0.2.1",
+                                "remote_as": "100",
+                                "description": "Test description",
+                                "shutdown": {  # Don't have in config, adding
+                                    "set": True,
+                                },
+                            },
+                            {
+                                "neighbor_address": "192.0.2.2",
+                                "remote_as": "200",
+                                "description": "Test description 2",
+                                "shutdown": {  # Have in config negating with false
+                                    "set": False,
+                                },
+                            },
+                        ],
+                    },
+                    "state": stt,
+                },
+            )
+            commands = [
+                "router bgp 6500",
+                "neighbor 192.0.2.1 shutdown",
+                "no neighbor 192.0.2.2 shutdown",
+            ]
+            result = self.execute_module(changed=True)
+            self.assertEqual(sorted(result["commands"]), sorted(commands))
+
+    def test_ios_bgp_global_action_states_no_default(self):
+        self.execute_show_command.return_value = dedent(
+            """\
+            router bgp 6500
+             bgp log-neighbor-changes
+             no bgp default ipv4-unicast
+             no bgp default route-target filter
+             neighbor 192.0.2.1 remote-as 100
+             neighbor 192.0.2.1 description Test description
+             neighbor 192.0.2.1 shutdown
+             neighbor 192.0.2.2 remote-as 200
+             neighbor 192.0.2.2 description Test description 2
+             neighbor 192.0.2.2 shutdown
+             neighbor 192.0.2.3 remote-as 300
+             neighbor 192.0.2.3 description Test description 3
+             neighbor 192.0.2.4 remote-as 400
+             neighbor 192.0.2.4 description Test description 4
+             !
+             address-family ipv4
+             exit-address-family
+            """,
+        )
+        for stt in ["replaced", "overridden"]:
+            set_module_args(
+                {
+                    "config": {
+                        "as_number": "6500",
+                        "bgp": {
+                            "default": {
+                                "ipv4_unicast": False,
+                                "route_target": {
+                                    "filter": False,
+                                },
+                            },
+                            "log_neighbor_changes": True,
+                        },
+                        "neighbors": [
+                            {
+                                "neighbor_address": "192.0.2.1",
+                                "remote_as": "100",
+                                "description": "Test description",
+                                "shutdown": {  # Have in config not adding again (idempotent)
+                                    "set": True,
+                                },
+                            },
+                            {
+                                "neighbor_address": "192.0.2.2",
+                                "remote_as": "200",
+                                "description": "Test description 2",  # Have in config but don't want (to be removed)
+                            },
+                            {
+                                "neighbor_address": "192.0.2.3",
+                                "remote_as": "300",
+                                "description": "Test description 3",  # Don't have in config don't want
+                            },
+                            {
+                                "neighbor_address": "192.0.2.4",
+                                "remote_as": "400",
+                                "description": "Test description 4",
+                                "shutdown": {  # Don't have in config, explicitly don't want
+                                    "set": False,
+                                },
+                            },
+                        ],
+                    },
+                    "state": stt,
+                },
+            )
+            commands = ["router bgp 6500", "no neighbor 192.0.2.2 shutdown"]
+            result = self.execute_module(changed=True)
+            self.assertEqual(sorted(result["commands"]), sorted(commands))
