@@ -32,7 +32,7 @@ options:
         type: str
     type: list
 requirements:
-- ciscoisesdk >= 2.0.1
+- ciscoisesdk >= 2.2.1
 - python >= 3.5
 notes:
   - SDK Method used are
@@ -70,7 +70,7 @@ ise_response:
     {
       "groups": [
         {
-          "groupName": "string",
+          "name": "string",
           "sid": "string",
           "type": "string"
         }
