@@ -10,6 +10,8 @@ module: identity_group
 short_description: Resource module for Identity Group
 description:
 - Manage operations create and update of the resource Identity Group.
+- This API creates an identity group.
+- This API allows the client to update an identity group.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
@@ -28,13 +30,21 @@ options:
     description: Identity Group's parent.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.2.1
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Identity Group reference
-  description: Complete reference of the Identity Group object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for IdentityGroups
+  description: Complete reference of the IdentityGroups API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!identitygroup
+notes:
+  - SDK Method used are
+    identity_groups.IdentityGroups.create_identity_group,
+    identity_groups.IdentityGroups.update_identity_group_by_id,
+
+  - Paths used are
+    post /ers/config/identitygroup,
+    put /ers/config/identitygroup/{id},
+
 """
 
 EXAMPLES = r"""
@@ -84,16 +94,18 @@ ise_response:
 ise_update_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
-  version_added: "1.1.0"
+  version_added: '1.1.0'
   type: dict
   sample: >
     {
       "UpdatedFieldsList": {
-        "updatedField": {
-          "field": "string",
-          "oldValue": "string",
-          "newValue": "string"
-        },
+        "updatedField": [
+          {
+            "field": "string",
+            "oldValue": "string",
+            "newValue": "string"
+          }
+        ],
         "field": "string",
         "oldValue": "string",
         "newValue": "string"
