@@ -7,9 +7,9 @@
 DOCUMENTATION = r"""
 ---
 module: mnt_sessions_by_session_id_info
-short_description: Information module for Mnt Sessions By Session Id
+short_description: Information module for MNT Sessions By Session Id
 description:
-- Get all Mnt Sessions By Session Id.
+- Get all MNT Sessions By Session Id.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
@@ -20,17 +20,19 @@ options:
     - Session_id path parameter.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.2.1
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Mnt Sessions By Session Id reference
-  description: Complete reference of the Mnt Sessions By Session Id object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    misc.Misc.get_sessions_by_session_id,
+
+  - Paths used are
+    get /Session/Active/SessionID/{session_id}/0,
+
 """
 
 EXAMPLES = r"""
-- name: Get all Mnt Sessions By Session Id
+- name: Get all MNT Sessions By Session Id
   cisco.ise.mnt_sessions_by_session_id_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
@@ -46,6 +48,6 @@ ise_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
   type: dict
-  sample:
-  - {}
+  sample: >
+    {}
 """
