@@ -11,6 +11,8 @@ short_description: Information module for Network Access Dictionary
 description:
 - Get all Network Access Dictionary.
 - Get Network Access Dictionary by name.
+- GET a dictionary by name.
+- Get all Dictionaries.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
@@ -21,13 +23,21 @@ options:
     - Name path parameter. The dictionary name.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.2.1
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Network Access Dictionary reference
-  description: Complete reference of the Network Access Dictionary object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Network Access - Dictionary
+  description: Complete reference of the Network Access - Dictionary API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+notes:
+  - SDK Method used are
+    network_access_dictionary.NetworkAccessDictionary.get_network_access_dictionaries,
+    network_access_dictionary.NetworkAccessDictionary.get_network_access_dictionary_by_name,
+
+  - Paths used are
+    get /network-access/dictionaries,
+    get /network-access/dictionaries/{name},
+
 """
 
 EXAMPLES = r"""
@@ -57,18 +67,15 @@ ise_response:
   type: dict
   sample: >
     {
-      "response": {
-        "description": "string",
-        "dictionaryAttrType": "string",
-        "id": "string",
-        "link": {
-          "href": "string",
-          "rel": "string",
-          "type": "string"
-        },
-        "name": "string",
-        "version": "string"
+      "description": "string",
+      "dictionaryAttrType": "string",
+      "id": "string",
+      "link": {
+        "href": "string",
+        "rel": "string",
+        "type": "string"
       },
+      "name": "string",
       "version": "string"
     }
 """
