@@ -41,7 +41,7 @@ options:
       is not provided.
     type: str
 requirements:
-- ciscoisesdk >= 2.0.1
+- ciscoisesdk >= 2.2.1
 - python >= 3.5
 seealso:
 - name: Cisco ISE documentation for sgVnMapping
@@ -50,8 +50,8 @@ seealso:
 notes:
   - SDK Method used are
     sg_vn_mapping.SgVnMapping.create_sg_vn_mapping,
-    sg_vn_mapping.SgVnMapping.delete_sg_vn_mapping_by_id,
-    sg_vn_mapping.SgVnMapping.update_sg_vn_mapping_by_id,
+    sg_vn_mapping.SgVnMapping.delete_sg_vn_mapping,
+    sg_vn_mapping.SgVnMapping.update_sg_vn_mapping,
 
   - Paths used are
     post /api/v1/trustsec/sgvnmapping,
@@ -124,7 +124,11 @@ ise_update_response:
   type: dict
   sample: >
     {
-      "code": 0,
-      "message": "string"
+      "id": "string",
+      "lastUpdate": "string",
+      "sgName": "string",
+      "sgtId": "string",
+      "vnId": "string",
+      "vnName": "string"
     }
 """
