@@ -23,9 +23,9 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 from textwrap import dedent
+from unittest.mock import patch
 
 from ansible_collections.cisco.nxos.plugins.modules import nxos_snmp_server
-from ansible_collections.cisco.nxos.tests.unit.compat.mock import patch
 
 from .nxos_module import TestNxosModule, set_module_args
 
@@ -391,7 +391,7 @@ class TestNxosSnmpServerModule(TestNxosModule):
         result = self.execute_module(changed=True)
         self.assertEqual(set(result["commands"]), set(commands))
 
-    def test_nxos_snmp_server_traps_replaced(self):
+    def test_nxos_snmp_server_traps_replaced_1(self):
         # test replaced for traps
         self.get_config.return_value = dedent(
             """\
@@ -482,7 +482,7 @@ class TestNxosSnmpServerModule(TestNxosModule):
         result = self.execute_module(changed=True)
         self.assertEqual(set(result["commands"]), set(commands))
 
-    def test_nxos_snmp_server_hosts_merged(self):
+    def test_nxos_snmp_server_hosts_merged_1(self):
         # test merged for hosts
         self.get_config.return_value = dedent(
             """\
@@ -591,7 +591,7 @@ class TestNxosSnmpServerModule(TestNxosModule):
         result = self.execute_module(changed=True)
         self.assertEqual(set(result["commands"]), set(commands))
 
-    def test_nxos_snmp_server_users_merged(self):
+    def test_nxos_snmp_server_users_merged_1(self):
         # test merged for users
         self.get_config.return_value = dedent(
             """\
@@ -662,18 +662,19 @@ class TestNxosSnmpServerModule(TestNxosModule):
         )
         commands = [
             "snmp-server user snmp_user_2 network-admin auth md5 0x5632724fb8ac3699296af26281e1d0f1 priv 0x5632724fb8ac3699296af26281e1d0f1"
-            " localizedkey engineID 2:2:2:2:2",
+            " localizedV2key engineID 2:2:2:2:2",
             "snmp-server user snmp_user_3 network-admin auth md5 0x5632724fb8ac3699296af26281e1d0f1 priv aes-128"
-            " 0x5632724fb8ac3699296af26281e1d0f1 localizedV2key engineID 3:3:3:3:3",
+            " 0x5632724fb8ac3699296af26281e1d0f1 localizedkey engineID 3:3:3:3:3",
             "snmp-server user snmp_user_1 network-admin auth md5 0x5632724fb8ac3699296af26281e1d0f1"
             " localizedkey engineID 1:1:1:1:1",
             "snmp-server user snmp_user_4 network-admin auth sha-256 0x5632724fb8ac3699296af26281e1d0f1 priv aes-128"
             " 0x5632724fb8ac3699296af26281e1d0f1 localizedkey engineID 4:4:4:4:4",
         ]
         result = self.execute_module(changed=True)
+        print(result["commands"])
         self.assertEqual(set(result["commands"]), set(commands))
 
-    def test_nxos_snmp_server_users_merged(self):
+    def test_nxos_snmp_server_users_merged_2(self):
         # test merged for users
         self.get_config.return_value = dedent(
             """\
@@ -705,7 +706,9 @@ class TestNxosSnmpServerModule(TestNxosModule):
                                     algorithm="md5",
                                     password="0x5632724fb8ac3699296af262",
                                     engine_id="2:2:2:2:2",
-                                    priv=dict(privacy_password="0x5632724fb8ac3699296af262"),
+                                    priv=dict(
+                                        privacy_password="0x5632724fb8ac3699296af262",
+                                    ),
                                     localizedv2_key=True,
                                 ),
                             ),
@@ -793,10 +796,8 @@ class TestNxosSnmpServerModule(TestNxosModule):
             ignore_provider_arg,
         )
         commands = [
-            "no snmp-server user user2 network-admin auth md5 0x5632724fb8ac3699296af262 priv"
-            " 0x5632724fb8ac3699296af262 localizedkey engineID 2:2:2:2:2",
-            "no snmp-server user user3 network-admin auth md5 0x5632724fb8ac3699296af262 priv"
-            " aes-128 0x5632724fb8ac3699296af262 localizedkey engineID 3:3:3:3:3",
+            "no snmp-server user user2",
+            "no snmp-server user user3",
             "snmp-server user user4 network-admin auth md5 0x5632724fb8ac3699296af262 priv aes-128"
             " 0x5632724fb8ac3699296af262 localizedkey engineID 3:3:3:3:3",
         ]
@@ -854,7 +855,7 @@ class TestNxosSnmpServerModule(TestNxosModule):
                 running_config=dedent(
                     """\
                     snmp-server community private group network-admin
-                    snmp-server community public use-ipv4acl myacl
+                    snmp-server community public use-ipv4acl myacl use-ipv6acl myaclv6
                     snmp-server globalEnforcePriv
                     snmp-server tcp-session auth
                     snmp-server counter cache timeout 1800
@@ -885,7 +886,7 @@ class TestNxosSnmpServerModule(TestNxosModule):
             contact="testswitch@localhost",
             communities=[
                 dict(name="private", group="network-admin"),
-                dict(name="public", use_ipv4acl="myacl"),
+                dict(name="public", use_ipv4acl="myacl", use_ipv6acl="myaclv6"),
             ],
             context=dict(name="public", vrf="siteA"),
             counter=dict(cache=dict(timeout=1800)),
@@ -908,7 +909,9 @@ class TestNxosSnmpServerModule(TestNxosModule):
                             algorithm="md5",
                             password="0x7d425fbf09417c44bca69e1d9e9ce889",
                             localized_key=True,
-                            priv=dict(privacy_password="0x7d425fbf09417c44bca69e1d9e9ce889"),
+                            priv=dict(
+                                privacy_password="0x7d425fbf09417c44bca69e1d9e9ce889",
+                            ),
                         ),
                     ),
                     dict(
@@ -935,6 +938,10 @@ class TestNxosSnmpServerModule(TestNxosModule):
                     contact="testswitch@localhost",
                     context=dict(name="public", vrf="siteA"),
                     counter=dict(cache=dict(timeout=1800)),
+                    communities=[
+                        dict(name="private", group="network-admin"),
+                        dict(name="public", use_ipv4acl="myacl", use_ipv6acl="myaclv6"),
+                    ],
                     drop=dict(unknown_engine_id=True, unknown_user=True),
                     engine_id=dict(local="'00:00:00:63:00:01:00:10:20:15:10:03'"),
                     global_enforce_priv=True,
@@ -967,6 +974,8 @@ class TestNxosSnmpServerModule(TestNxosModule):
             "snmp-server location lab",
             "snmp-server mib community-map public context public1",
             "snmp-server source-interface traps Ethernet1/2",
+            "snmp-server community private group network-admin",
+            "snmp-server community public use-ipv4acl myacl use-ipv6acl myaclv6",
         ]
         result = self.execute_module(changed=False)
         self.assertEqual(set(result["rendered"]), set(rendered))
