@@ -6,19 +6,13 @@ from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
 
-import json
 import os
 import textwrap
 
-import pytest
-
-from mock import MagicMock
-
 from ansible import constants as C
-from ansible.errors import AnsibleError
-from ansible.inventory.data import InventoryData
 from ansible.inventory.manager import InventoryManager
 from ansible.module_utils.common.text.converters import to_native
+from ansible.utils.unsafe_proxy import AnsibleUnsafe
 
 from ansible_collections.community.internal_test_tools.tests.unit.mock.path import mock_unfrackpath_noop
 from ansible_collections.community.internal_test_tools.tests.unit.mock.loader import DictDataLoader
@@ -27,8 +21,6 @@ from ansible_collections.community.internal_test_tools.tests.unit.utils.open_url
     OpenUrlProxy,
 )
 
-from ansible_collections.community.dns.plugins.inventory.hetzner_dns_records import InventoryModule
-
 
 HETZNER_DEFAULT_ZONE = {
     'id': '42',
@@ -116,6 +108,68 @@ HETZNER_JSON_DEFAULT_ENTRIES = [
     },
 ]
 
+HETZNER_JSON_DEFAULT_ENTRIES_UNSAFE = [
+    {
+        'id': '125',
+        'type': 'A',
+        'name': '@',
+        'value': '1.2.{3.4',
+        'ttl': 3600,
+        'zone_id': '42',
+        'created': '2021-07-09T11:18:37Z',
+        'modified': '2021-07-09T11:18:37Z',
+    },
+    {
+        'id': '126',
+        'type': 'A',
+        'name': '*',
+        'value': '1.2.{3.5',
+        'ttl': 3600,
+        'zone_id': '42',
+        'created': '2021-07-09T11:18:37Z',
+        'modified': '2021-07-09T11:18:37Z',
+    },
+    {
+        'id': '127',
+        'type': 'AAAA',
+        'name': '@',
+        'value': '2001:1:2::{3',
+        'ttl': 3600,
+        'zone_id': '42',
+        'created': '2021-07-09T11:18:37Z',
+        'modified': '2021-07-09T11:18:37Z',
+    },
+    {
+        'id': '128',
+        'type': 'AAAA',
+        'name': 'foo',
+        'value': '2001:1:2::{4',
+        'ttl': 3600,
+        'zone_id': '42',
+        'created': '2021-07-09T11:18:37Z',
+        'modified': '2021-07-09T11:18:37Z',
+    },
+    {
+        'id': '129',
+        'type': 'MX',
+        'name': '@',
+        'value': '10 example.com',
+        'ttl': 3600,
+        'zone_id': '42',
+        'created': '2021-07-09T11:18:37Z',
+        'modified': '2021-07-09T11:18:37Z',
+    },
+    {
+        'id': '130',
+        'type': 'CNAME',
+        'name': 'bar',
+        'value': 'example.org.',
+        'zone_id': '42',
+        'created': '2021-07-09T11:18:37Z',
+        'modified': '2021-07-09T11:18:37Z',
+    },
+]
+
 HETZNER_JSON_BAD_ENTRIES = [
     {
         'id': '125',
@@ -143,6 +197,10 @@ HETZNER_JSON_ZONE_RECORDS_GET_RESULT = {
     'records': HETZNER_JSON_DEFAULT_ENTRIES,
 }
 
+HETZNER_JSON_ZONE_RECORDS_GET_RESULT_UNSAFE = {
+    'records': HETZNER_JSON_DEFAULT_ENTRIES_UNSAFE,
+}
+
 HETZNER_JSON_ZONE_RECORDS_GET_RESULT_2 = {
     'records': HETZNER_JSON_BAD_ENTRIES,
 }
@@ -178,7 +236,7 @@ def test_inventory_file_simple(mocker):
     plugin: community.dns.hetzner_dns_records
     hetzner_token: foo
     zone_name: example.com
-    filters:
+    simple_filters:
       type: A
     """)}
 
@@ -198,7 +256,7 @@ def test_inventory_file_simple(mocker):
         .expect_query_values('page', '1')
         .expect_query_values('per_page', '100')
         .return_header('Content-Type', 'application/json')
-        .result_json(HETZNER_JSON_ZONE_RECORDS_GET_RESULT),
+        .result_json(HETZNER_JSON_ZONE_RECORDS_GET_RESULT_UNSAFE),
     ])
     mocker.patch('ansible_collections.community.dns.plugins.module_utils.http.open_url', open_url)
     mocker.patch('ansible.inventory.manager.unfrackpath', mock_unfrackpath_noop)
@@ -215,8 +273,10 @@ def test_inventory_file_simple(mocker):
     assert 'bar.example.com' not in im._inventory.hosts
     assert im._inventory.get_host('example.com') in im._inventory.groups['ungrouped'].hosts
     assert im._inventory.get_host('*.example.com') in im._inventory.groups['ungrouped'].hosts
-    assert im._inventory.get_host('example.com').get_vars()['ansible_host'] == '1.2.3.4'
-    assert im._inventory.get_host('*.example.com').get_vars()['ansible_host'] == '1.2.3.5'
+    assert im._inventory.get_host('example.com').get_vars()['ansible_host'] == '1.2.{3.4'
+    assert im._inventory.get_host('*.example.com').get_vars()['ansible_host'] == '1.2.{3.5'
+    assert isinstance(im._inventory.get_host('example.com').get_vars()['ansible_host'], AnsibleUnsafe)
+    assert isinstance(im._inventory.get_host('*.example.com').get_vars()['ansible_host'], AnsibleUnsafe)
     assert len(im._inventory.groups['ungrouped'].hosts) == 2
     assert len(im._inventory.groups['all'].hosts) == 0
 
@@ -229,7 +289,7 @@ def test_inventory_file_collision(mocker):
     plugin: community.dns.hetzner_dns_records
     hetzner_token: '{{ "foo" }}'
     zone_name: '{{ "example." ~ "com" }}'
-    filters:
+    simple_filters:
       type:
         - A
         - AAAA
