@@ -15,7 +15,8 @@ description:
   - Initialises a MongoDB replicaset in a new deployment.
   - Validates the replicaset name for existing deployments.
   - Advanced replicaset member (re)configuration possible (see examples).
-  - Initialize the replicaset before adding users.
+  - Initialize the replicaset before adding users as per \
+    [best practice](https://www.mongodb.com/docs/manual/tutorial/deploy-replica-set-with-keyfile-access-control/).
 author: Rhys Campbell (@rhysmeister)
 version_added: "1.0.0"
 
@@ -111,7 +112,8 @@ options:
     default: hello
 notes:
 - Requires the pymongo Python package on the remote host, version 2.4.2+. This
-  can be installed using pip or the OS package manager. @see U(http://api.mongodb.org/python/current/installation.html)
+  can be installed using pip or the OS package manager.
+  @see U(http://api.mongodb.org/python/current/installation.html)
 requirements:
 - pymongo
 '''
@@ -553,8 +555,11 @@ def main():
     debug = module.params['debug']
     cluster_cmd = module.params['cluster_cmd']
 
+    # Count voting members
+    voting_members = sum([1 if not isinstance(m, dict) or m.get("votes", 1) == 1 else 0 for m in members])
+
     if validate and reconfigure is False:
-        if len(members) <= 2 or len(members) % 2 == 0:
+        if len(members) <= 2 or voting_members % 2 == 0:
             module.fail_json(msg="MongoDB Replicaset validation failed. Invalid number of replicaset members.")
         if arbiter_at_index is not None and len(members) - 1 < arbiter_at_index:
             module.fail_json(msg="MongoDB Replicaset validation failed. Invalid arbiter index.")
