@@ -59,13 +59,13 @@ def test_mongod_replicaset(host):
         port = 27017
     cmd = "mongosh --port {0} --eval 'rs.status()'".format(port)
     # We only want to run this once
-    if host.ansible.get_variables()['inventory_hostname'] == "amazonlinux":
+    if host.ansible.get_variables()['inventory_hostname'] == "fedora":
         r = host.run(cmd)
         assert "rs0" in r.stdout
-        assert "centos_7:{0}".format(port) in r.stdout
-        assert "amazonlinux:{0}".format(port) in r.stdout
-        assert "ubuntu_18:{0}".format(port) in r.stdout
-        assert "debian_buster:{0}".format(port) in r.stdout
+        # assert "almalinux_8:{0}".format(port) in r.stdout
+        # assert "fedora:{0}".format(port) in r.stdout
+        assert "ubuntu_22_04:{0}".format(port) in r.stdout
+        assert "ubuntu_22:{0}".format(port) in r.stdout
         assert "debian_bullseye:{0}".format(port) in r.stdout
 
 
