@@ -16,28 +16,27 @@ module: vmware_guest_snapshot
 short_description: Manages virtual machines snapshots in vCenter
 description:
     - This module can be used to create, delete and update snapshot(s) of the given virtual machine.
-    - All parameters and VMware object names are case sensitive.
 author:
     - Loic Blot (@nerzhul) <loic.blot@unix-experience.fr>
 options:
    state:
      description:
      - Manage snapshot(s) attached to a specific virtual machine.
-     - If set to C(present) and snapshot absent, then will create a new snapshot with the given name.
-     - If set to C(present) and snapshot present, then no changes are made.
-     - If set to C(absent) and snapshot present, then snapshot with the given name is removed.
-     - If set to C(absent) and snapshot absent, then no changes are made.
-     - If set to C(revert) and snapshot present, then virtual machine state is reverted to the given snapshot.
-     - If set to C(revert) and snapshot absent, then no changes are made.
-     - If set to C(remove_all) and snapshot(s) present, then all snapshot(s) will be removed.
-     - If set to C(remove_all) and snapshot(s) absent, then no changes are made.
+     - If set to V(present) and snapshot absent, then will create a new snapshot with the given name.
+     - If set to V(present) and snapshot present, then no changes are made.
+     - If set to V(absent) and snapshot present, then snapshot with the given name is removed.
+     - If set to V(absent) and snapshot absent, then no changes are made.
+     - If set to V(revert) and snapshot present, then virtual machine state is reverted to the given snapshot.
+     - If set to V(revert) and snapshot absent, then no changes are made.
+     - If set to V(remove_all) and snapshot(s) present, then all snapshot(s) will be removed.
+     - If set to V(remove_all) and snapshot(s) absent, then no changes are made.
      choices: ['present', 'absent', 'revert', 'remove_all']
      default: 'present'
      type: str
    name:
      description:
      - Name of the virtual machine to work with.
-     - This is required parameter, if C(uuid) or C(moid) is not supplied.
+     - This is required parameter, if O(uuid) or O(moid) is not supplied.
      type: str
    name_match:
      description:
@@ -48,12 +47,12 @@ options:
    uuid:
      description:
      - UUID of the instance to manage if known, this is VMware's BIOS UUID by default.
-     - This is required if C(name) or C(moid) parameter is not supplied.
+     - This is required if O(name) or O(moid) parameter is not supplied.
      type: str
    moid:
      description:
      - Managed Object ID of the instance to manage if known, this is a unique identifier only within a single vCenter instance.
-     - This is required if C(name) or C(uuid) is not supplied.
+     - This is required if O(name) or O(uuid) is not supplied.
      type: str
    use_instance_uuid:
      description:
@@ -63,7 +62,7 @@ options:
    folder:
      description:
      - Destination folder, absolute or relative path to find an existing guest.
-     - This is required parameter, if C(name) is supplied.
+     - This is required parameter, if O(name) is supplied.
      - The folder should include the datacenter. ESX's datacenter is ha-datacenter.
      - 'Examples:'
      - '   folder: /ha-datacenter/vm'
@@ -84,12 +83,12 @@ options:
    snapshot_name:
      description:
      - Sets the snapshot name to manage.
-     - This param or C(snapshot_id) is required only if state is not C(remove_all)
+     - This param or O(snapshot_id) is required only if O(state) is not C(remove_all)
      type: str
    snapshot_id:
      description:
      - Sets the snapshot id to manage.
-     - This param is available when state is C(absent).
+     - This param is available when O(state=absent).
      type: int
      version_added: 3.10.0
    description:
@@ -99,24 +98,24 @@ options:
      type: str
    quiesce:
      description:
-     - If set to C(true) and virtual machine is powered on, it will quiesce the file system in virtual machine.
+     - If set to V(true) and virtual machine is powered on, it will quiesce the file system in virtual machine.
      - Note that VMware Tools are required for this flag.
-     - If virtual machine is powered off or VMware Tools are not available, then this flag is set to C(false).
-     - If virtual machine does not provide capability to take quiesce snapshot, then this flag is set to C(false).
+     - If virtual machine is powered off or VMware Tools are not available, then this flag is set to V(false).
+     - If virtual machine does not provide capability to take quiesce snapshot, then this flag is set to V(false).
      required: false
      type: bool
      default: false
    memory_dump:
      description:
-     - If set to C(true), memory dump of virtual machine is also included in snapshot.
+     - If set to V(true), memory dump of virtual machine is also included in snapshot.
      - Note that memory snapshots take time and resources, this will take longer time to create.
-     - If virtual machine does not provide capability to take memory snapshot, then this flag is set to C(false).
+     - If virtual machine does not provide capability to take memory snapshot, then this flag is set to V(false).
      required: false
      type: bool
      default: false
    remove_children:
      description:
-     - If set to C(true) and state is set to C(absent), then entire snapshot subtree is set for removal.
+     - If set to V(true) and O(state=absent), then entire snapshot subtree is set for removal.
      required: false
      type: bool
      default: false
