@@ -1,4 +1,4 @@
-# (c) 2019-2022, NetApp, Inc
+# (c) 2019-2023, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 ''' unit tests ONTAP Ansible module: na_ontap_quotas '''
@@ -10,6 +10,7 @@ import pytest
 
 from ansible_collections.netapp.ontap.tests.unit.compat.mock import patch
 import ansible_collections.netapp.ontap.plugins.module_utils.netapp as netapp_utils
+# pylint: disable=unused-import
 from ansible_collections.netapp.ontap.tests.unit.plugins.module_utils.ansible_mocks import assert_no_warnings,\
     assert_warning_was_raised, call_main, patch_ansible, create_module, create_and_apply, expect_and_capture_ansible_exception, print_warnings
 from ansible_collections.netapp.ontap.tests.unit.framework.mock_rest_and_zapi_requests import patch_request_and_invoke, register_responses
@@ -54,12 +55,38 @@ SRR = rest_responses({
                     "target": {
                         "name": "20:05:00:50:56:b3:0c:fa"
                     },
+                },
+                {
+                    "svm": {
+                        "uuid": "671aa46e-11ad-11ec-a267-005056b30cfa",
+                        "name": "ansible"
+                    },
+                    "files": {
+                        "hard_limit": "100",
+                        "soft_limit": "80"
+                    },
+                    "qtree": {
+                        "id": "1",
+                        "name": "qt1"
+                    },
+                    "space": {
+                        "hard_limit": "1222800",
+                        "soft_limit": "51200"
+                    },
+                    "type": "user",
+                    "user_mapping": False,
+                    "users": [{"id": "757"}],
+                    "uuid": "264a9e0b-2e03-11e9-a610-005056a7b72d",
+                    "volume": {"name": "fv", "uuid": "264a9e0b-2e03-11e9-a610-005056a7b72da"},
+                    "target": {
+                        "name": "20:05:00:50:56:b3:0c:fa"
+                    },
                 }
             ],
             "num_records": 1
         }, None
     ),
-    'quota_record_0_empty_limtis': (200, {"records": [{
+    'quota_record_0_empty_limits': (200, {"records": [{
         "svm": {"name": "ansible"},
         "files": {"hard_limit": 0},
         "qtree": {"id": "1", "name": "qt1"},
@@ -102,9 +129,16 @@ SRR = rest_responses({
     "error_5308568": (409, None, {'code': 5308568, 'message': 'Expected create error'}),
     "error_5308571": (409, None, {'code': 5308571, 'message': 'Expected create error'}),
     "error_5308567": (409, None, {'code': 5308567, 'message': 'Expected modify error'}),
+    'error_rest': (404, None, {"message": "temporarily locked from changes", "code": "4", "target": "uuid"}),
     "volume_uuid": (200, {"records": [{
         'uuid': 'sdgthfd'
-    }], 'num_records': 1}, None)
+    }], 'num_records': 1}, None),
+    'job_info': (200, {
+        "job": {
+            "uuid": "d78811c1-aebc-11ec-b4de-005056b30cfa",
+            "_links": {"self": {"href": "/api/cluster/jobs/d78811c1-aebc-11ec-b4de-005056b30cfa"}}
+        }}, None),
+    'job_not_found': (404, "", {"message": "entry doesn't exist", "code": "4", "target": "uuid"})
 })
 
 
@@ -433,12 +467,47 @@ def test_rest_successful_create():
         ('GET', 'storage/volumes', SRR['quota_status']),
         ('POST', 'storage/quota/rules', SRR['empty_good']),
     ])
-    module_args = {
-        "users": [{"name": "quota_user"}],
-    }
     assert create_and_apply(my_module, ARGS_REST)
 
 
+def test_rest_successful_create_userid():
+    '''Test successful rest create with users.id with idempotency check'''
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest']),
+        ('GET', 'storage/quota/rules', SRR['empty_records']),
+        ('GET', 'storage/volumes', SRR['quota_status']),
+        ('POST', 'storage/quota/rules', SRR['empty_good']),
+
+        ('GET', 'cluster', SRR['is_rest']),
+        ('GET', 'storage/quota/rules', SRR['quota_record']),
+        ('GET', 'storage/volumes', SRR['quota_status']),
+    ])
+    module_args = {
+        "quota_target": "757",
+    }
+    assert create_and_apply(my_module, ARGS_REST, module_args)
+    assert create_and_apply(my_module, ARGS_REST, module_args)['changed'] is False
+
+
+@patch('time.sleep')
+def test_rest_successful_create_job_error(sleep):
+    '''Test successful rest create'''
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest']),
+        ('GET', 'storage/quota/rules', SRR['empty_records']),
+        ('GET', 'storage/volumes', SRR['quota_status']),
+        ('POST', 'storage/quota/rules', SRR['job_info']),
+        ('GET', 'cluster/jobs/d78811c1-aebc-11ec-b4de-005056b30cfa', SRR['job_not_found']),
+        ('GET', 'cluster/jobs/d78811c1-aebc-11ec-b4de-005056b30cfa', SRR['job_not_found']),
+        ('GET', 'cluster/jobs/d78811c1-aebc-11ec-b4de-005056b30cfa', SRR['job_not_found']),
+        ('GET', 'cluster/jobs/d78811c1-aebc-11ec-b4de-005056b30cfa', SRR['job_not_found']),
+        ('GET', 'storage/volumes', SRR['volume_uuid'])
+    ])
+    assert create_and_apply(my_module, ARGS_REST)
+    print_warnings()
+    assert_warning_was_raised('Ignoring job status, assuming success.')
+
+
 def test_rest_error_create():
     '''Test error rest create'''
     register_responses([
@@ -523,6 +592,41 @@ def test_modify_rest_error():
     assert 'Error on modifying quotas rule:' in error
 
 
+@patch('time.sleep')
+def test_modify_rest_temporary_locked_error(sleep):
+    ''' Test negative modify with rest API'''
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest']),
+        ('GET', 'storage/quota/rules', SRR['quota_record']),
+        ('GET', 'storage/volumes', SRR['quota_status']),
+        # wait for 60s if we get temporary locl error.
+        ('PATCH', 'storage/quota/rules/264a9e0b-2e03-11e9-a610-005056a7b72d', SRR['error_rest']),
+        ('PATCH', 'storage/quota/rules/264a9e0b-2e03-11e9-a610-005056a7b72d', SRR['error_rest']),
+        ('PATCH', 'storage/quota/rules/264a9e0b-2e03-11e9-a610-005056a7b72d', SRR['success']),
+
+        ('GET', 'cluster', SRR['is_rest']),
+        ('GET', 'storage/quota/rules', SRR['quota_record']),
+        ('GET', 'storage/volumes', SRR['quota_status']),
+        # error persist even after 60s
+        ('PATCH', 'storage/quota/rules/264a9e0b-2e03-11e9-a610-005056a7b72d', SRR['error_rest']),
+        ('PATCH', 'storage/quota/rules/264a9e0b-2e03-11e9-a610-005056a7b72d', SRR['error_rest']),
+        ('PATCH', 'storage/quota/rules/264a9e0b-2e03-11e9-a610-005056a7b72d', SRR['error_rest']),
+
+        # wait 60s in create for temporary locked error.
+        ('GET', 'cluster', SRR['is_rest']),
+        ('GET', 'storage/quota/rules', SRR['empty_records']),
+        ('GET', 'storage/volumes', SRR['quota_status']),
+        ('POST', 'storage/quota/rules', SRR['error_rest']),
+        ('POST', 'storage/quota/rules', SRR['success']),
+    ])
+    module_args = {
+        'perform_user_mapping': True
+    }
+    assert create_and_apply(my_module, ARGS_REST, module_args)['changed']
+    assert 'Error on modifying quotas rule:' in create_and_apply(my_module, ARGS_REST, module_args, fail=True)['msg']
+    assert create_and_apply(my_module, ARGS_REST, module_args)['changed']
+
+
 def test_rest_successful_create_idempotency():
     '''Test successful rest create'''
     register_responses([
@@ -530,10 +634,10 @@ def test_rest_successful_create_idempotency():
         ('GET', 'storage/quota/rules', SRR['quota_record']),
         ('GET', 'storage/volumes', SRR['quota_status']),
         ('GET', 'cluster', SRR['is_rest']),
-        ('GET', 'storage/quota/rules', SRR['quota_record_0_empty_limtis']),
+        ('GET', 'storage/quota/rules', SRR['quota_record_0_empty_limits']),
         ('GET', 'storage/volumes', SRR['quota_status']),
         ('GET', 'cluster', SRR['is_rest']),
-        ('GET', 'storage/quota/rules', SRR['quota_record_0_empty_limtis']),
+        ('GET', 'storage/quota/rules', SRR['quota_record_0_empty_limits']),
         ('GET', 'storage/volumes', SRR['quota_status'])
     ])
     assert create_and_apply(my_module, ARGS_REST)['changed'] is False
