@@ -10,25 +10,18 @@ import json
 import pytest
 import sys
 
-# try:
-#     from requests import Response
-# except ImportError:
-#     if sys.version_info < (2, 7):
-#         pytestmark = pytest.mark.skip("Skipping Unit Tests on 2.6 as requests is not available")
-#     else:
-#         raise
-
+import ansible_collections.netapp.storagegrid.plugins.module_utils.netapp as netapp_utils
 from ansible_collections.netapp.storagegrid.tests.unit.compat import unittest
-from ansible_collections.netapp.storagegrid.tests.unit.compat.mock import (
-    patch,
-    Mock,
-)
+from ansible_collections.netapp.storagegrid.tests.unit.compat.mock import patch
 from ansible.module_utils import basic
 from ansible.module_utils._text import to_bytes
 from ansible_collections.netapp.storagegrid.plugins.modules.na_sg_grid_gateway import (
     SgGridGateway as grid_gateway_module,
 )
 
+if not netapp_utils.HAS_REQUESTS and sys.version_info < (2, 7):
+    pytestmark = pytest.mark.skip("Skipping Unit Tests on 2.6 as requests is not available")
+
 # REST API canned responses when mocking send_request
 SRR = {
     # common responses
@@ -130,7 +123,22 @@ SRR = {
                         },
                     ],
                     "gatewayCidr": "192.168.14.1/24",
-                }
+                },
+                {
+                    "id": "da9ac524-9a16-4be0-9d6e-ec9b22218e75",
+                    "name": "site1_gw",
+                    "description": "another test ha group",
+                    "virtualIps": ["10.193.204.200"],
+                    "interfaces": [
+                        {
+                            "nodeId": "7bb5bf05-a04c-4344-8abd-08c5c4048666",
+                            "nodeName": "SITE1-GW1",
+                            "interface": "eth0",
+                            "preferredMaster": True,
+                        },
+                    ],
+                    "gatewayCidr": "192.168.14.1/24",
+                },
             ]
         },
         None,
@@ -574,7 +582,7 @@ class TestMyModule(unittest.TestCase):
     def test_create_na_sg_grid_gateway_port_with_ha_group_binding_pass(self, mock_request):
         args = self.set_args_create_na_sg_grid_gateway_port()
         args["binding_mode"] = "ha-groups"
-        args["ha_groups"] = "site1_primary"
+        args["ha_groups"] = ["site1_primary", "da9ac524-9a16-4be0-9d6e-ec9b22218e75"]
         set_module_args(args)
         mock_request.side_effect = [
             SRR["version_116"],  # get
@@ -590,6 +598,21 @@ class TestMyModule(unittest.TestCase):
         print("Info: test_create_na_sg_grid_gateway_port_with_ha_group_binding_pass: %s" % repr(exc.value.args[0]))
         assert exc.value.args[0]["changed"]
 
+    # test create with bad ha group ID
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
+    def test_create_na_sg_grid_gateway_port_with_bad_ha_group_binding_fail(self, mock_request):
+        mock_request.side_effect = [
+            SRR["version_116"],  # get
+            SRR["ha_groups"],  # get
+        ]
+        with pytest.raises(AnsibleFailJson) as exc:
+            args = self.set_args_create_na_sg_grid_gateway_port()
+            args["binding_mode"] = "ha-groups"
+            args["ha_groups"] = ["fffac524-9a16-4be0-9d6e-ec9b22218e75"]
+            set_module_args(args)
+            grid_gateway_module()
+        print("Info: test_create_na_sg_grid_gateway_port_with_bad_ha_group_binding_fail: %s" % repr(exc.value.args[0]))
+
     # test create with node interfaces
     @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
     def test_create_na_sg_grid_gateway_port_with_node_interface_binding_pass(self, mock_request):
