@@ -21,7 +21,6 @@ version_added: '1.0.0'
 short_description: Configure FlashArray Directory Service Roles
 description:
 - Set or erase directory services role configurations.
-- Only available for FlashArray running Purity 5.2.0 or higher
 author:
 - Pure Storage Ansible Team (@sdodsley) <pure-ansible-team@purestorage.com>
 options:
@@ -61,14 +60,14 @@ extends_documentation_fragment:
 
 EXAMPLES = r"""
 - name: Delete exisitng array_admin directory service role
-  purefa_dsrole:
+  purestorage.flasharray.purefa_dsrole:
     role: array_admin
     state: absent
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
 
 - name: Create array_admin directory service role
-  purefa_dsrole:
+  purestorage.flasharray.purefa_dsrole:
     role: array_admin
     group_base: "OU=PureGroups,OU=SANManagers"
     group: pureadmins
@@ -76,7 +75,7 @@ EXAMPLES = r"""
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
 
 - name: Update ops_admin directory service role
-  purefa_dsrole:
+  purestorage.flasharray.purefa_dsrole:
     role: ops_admin
     group_base: "OU=PureGroups"
     group: opsgroup
@@ -88,34 +87,42 @@ RETURN = r"""
 """
 
 
+HAS_PYPURECLIENT = True
+try:
+    from pypureclient.flasharray import DirectoryServiceRole, FixedReference
+except ImportError:
+    HAS_PYPURECLIENT = False
+
+
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.purestorage.flasharray.plugins.module_utils.purefa import (
-    get_system,
+    get_array,
     purefa_argument_spec,
 )
 
 
 def update_role(module, array):
     """Update Directory Service Role"""
-    changed = True
-    if not module.check_mode:
-        changed = False
-        role = array.list_directory_service_roles(names=[module.params["role"]])
-        if (
-            role[0]["group_base"] != module.params["group_base"]
-            or role[0]["group"] != module.params["group"]
-        ):
-            try:
-                array.set_directory_service_roles(
-                    names=[module.params["role"]],
-                    group_base=module.params["group_base"],
-                    group=module.params["group"],
-                )
-                changed = True
-            except Exception:
+    changed = False
+    role = list(array.get_directory_service_roles(names=[module.params["role"]]).items)[
+        0
+    ]
+    if (
+        role.group_base != module.params["group_base"]
+        or role.group != module.params["group"]
+    ):
+        changed = True
+        if not module.check_mode:
+            res = array.patch_directory_service_roles(
+                names=[module.params["role"]],
+                directory_services_roles=DirectoryServiceRole(
+                    group_base=module.params["group_base"], group=module.params["group"]
+                ),
+            )
+            if res.status_code != 200:
                 module.fail_json(
-                    msg="Update Directory Service Role {0} failed".format(
-                        module.params["role"]
+                    msg="Update Directory Service Role {0} failed.Error: {1}".format(
+                        module.params["role"], res.errors[0].message
                     )
                 )
     module.exit_json(changed=changed)
@@ -125,14 +132,11 @@ def delete_role(module, array):
     """Delete Directory Service Role"""
     changed = True
     if not module.check_mode:
-        try:
-            array.set_directory_service_roles(
-                names=[module.params["role"]], group_base="", group=""
-            )
-        except Exception:
+        res = array.delete_directory_service_roles(names=[module.params["role"]])
+        if res.status_code != 200:
             module.fail_json(
-                msg="Delete Directory Service Role {0} failed".format(
-                    module.params["role"]
+                msg="Delete Directory Service Role {0} failed. Error: {1}".format(
+                    module.params["role"], res.errors[0].message
                 )
             )
     module.exit_json(changed=changed)
@@ -140,20 +144,23 @@ def delete_role(module, array):
 
 def create_role(module, array):
     """Create Directory Service Role"""
-    changed = True
-    if not module.check_mode:
-        try:
-            array.set_directory_service_roles(
+    changed = False
+    if not module.params["group"] == "" or not module.params["group_base"] == "":
+        changed = True
+        if not module.check_mode:
+            res = array.post_directory_service_roles(
                 names=[module.params["role"]],
-                group_base=module.params["group_base"],
-                group=module.params["group"],
+                directory_service_role=DirectoryServiceRole(
+                    group_base=module.params["group_base"], group=module.params["group"]
+                ),
             )
-        except Exception:
-            module.fail_json(
-                msg="Create Directory Service Role {0} failed".format(
-                    module.params["role"]
+            if res.status_code != 200:
+                module.fail_json(
+                    msg="Create Directory Service Role {0} failed. Error: {1}".format(
+                        module.params["role"],
+                        res.errors[0].message,
+                    )
                 )
-            )
     module.exit_json(changed=changed)
 
 
@@ -178,11 +185,18 @@ def main():
         argument_spec, required_together=required_together, supports_check_mode=True
     )
 
+    if not HAS_PYPURECLIENT:
+        module.fail_json(msg="pypureclient sdk is required for this module")
+
     state = module.params["state"]
-    array = get_system(module)
+    array = get_array(module)
     role_configured = False
-    role = array.list_directory_service_roles(names=[module.params["role"]])
-    if role[0]["group"] is not None:
+    role = list(
+        array.get_directory_service_roles(
+            roles=[FixedReference(name=module.params["role"])]
+        ).items
+    )[0]
+    if getattr(role, "group", None) is not None:
         role_configured = True
 
     if state == "absent" and role_configured:
