@@ -49,12 +49,12 @@ options:
     description:
     - Define whether to eradicate the volume on delete or leave in trash.
     type: bool
-    default: 'no'
+    default: false
   overwrite:
     description:
     - Define whether to overwrite a target volume if it already exisits.
     type: bool
-    default: 'no'
+    default: false
   size:
     description:
     - Volume size in M, G, T or P units.
@@ -86,6 +86,7 @@ options:
       See associated descriptions
     - Only supported from Purity//FA v6.0.0 and higher
     type: str
+    default: ""
   bw_qos:
     description:
     - Bandwidth limit for volume in M or G units.
@@ -119,8 +120,43 @@ options:
     description:
     - Name of exisitng, not deleted, protection group to add volume to
     - Only application for volume(s) creation
+    - Superceeded from Purity//FA 6.3.4 by I(add_to_pgs)
     type: str
     version_added: 1.8.0
+  priority_operator:
+    description:
+    - DMM Priority Adjustment operator
+    type: str
+    choices: [ '=', '+', '-' ]
+    version_added: '1.13.0'
+  priority_value:
+    description:
+    - DMM Priority Adjustment value
+    type: int
+    choices: [ -10, 0, 10 ]
+    version_added: '1.13.0'
+  with_default_protection:
+    description:
+    - Whether to add the default container protection groups to
+      those specified in I(add_to_pgs) as the inital protection
+      of a new volume.
+    type: bool
+    default: true
+    version_added: '1.14.0'
+  add_to_pgs:
+    description:
+    - A new volume will be added to the specified protection groups
+      on creation
+    type: list
+    elements: str
+    version_added: '1.14.0'
+  promotion_state:
+    description:
+    - Promote or demote the volume so that the volume starts or
+      stops accepting write requests.
+    type: str
+    choices: [ promoted, demoted ]
+    version_added: '1.16.0'
 extends_documentation_fragment:
 - purestorage.flasharray.purestorage.fa
 """
@@ -136,10 +172,20 @@ EXAMPLES = r"""
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
     state: present
 
+- name: Create new volume named foo with a DMM priority (Purity//FA 6.1.2+)
+  purestorage.flasharray.purefa_volume:
+    name: foo
+    size: 1T
+    priority_operator: +
+    priorty_value: 10
+    fa_url: 10.10.10.2
+    api_token: e31060a7-21fc-e277-6240-25983c6c4592
+    state: present
+
 - name: Create new volume named foo in pod bar in protection group pg1
   purestorage.flasharray.purefa_volume:
     name: bar::foo
-    prgoup: pg1
+    pgroup: pg1
     size: 1T
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
@@ -168,7 +214,7 @@ EXAMPLES = r"""
 - name: Delete and eradicate volume named foo
   purestorage.flasharray.purefa_volume:
     name: foo
-    eradicate: yes
+    eradicate: true
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
     state: absent
@@ -185,7 +231,7 @@ EXAMPLES = r"""
   purestorage.flasharray.purefa_volume:
     name: foo
     target: bar
-    overwrite: yes
+    overwrite: true
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
     state: present
@@ -259,6 +305,12 @@ volume:
         iops_limit:
             description: Volume IOPs limit
             type: int
+        priority_operator:
+            description: DMM Priority Adjustment operator
+            type: str
+        priority_value:
+            description: DMM Priority Adjustment value
+            type: int
 """
 
 HAS_PURESTORAGE = True
@@ -275,7 +327,13 @@ from ansible_collections.purestorage.flasharray.plugins.module_utils.purefa impo
     get_system,
     purefa_argument_spec,
 )
-
+from ansible_collections.purestorage.flasharray.plugins.module_utils.common import (
+    human_to_bytes,
+    human_to_real,
+)
+from ansible_collections.purestorage.flasharray.plugins.module_utils.version import (
+    LooseVersion,
+)
 
 QOS_API_VERSION = "1.14"
 VGROUPS_API_VERSION = "1.13"
@@ -286,6 +344,41 @@ IOPS_API_VERSION = "1.17"
 MULTI_VOLUME_VERSION = "2.2"
 PROMOTE_API_VERSION = "1.19"
 PURE_OUI = "naa.624a9370"
+PRIORITY_API_VERSION = "2.11"
+DEFAULT_API_VERSION = "2.16"
+VOLUME_PROMOTION_API_VERSION = "2.2"
+
+
+def _volfact(module, array):
+    api_version = array.get_rest_version()
+    volume_name = module.params["name"]
+    volume_data = list(array.get_volumes(names=[volume_name]).items)[0]
+    volfact = {
+        volume_name: {
+            "size": volume_data.provisioned,
+            "serial": volume_data.serial,
+            "created": time.strftime(
+                "%Y-%m-%d %H:%M:%S", time.localtime(volume_data.created / 1000)
+            ),
+            "page83_naa": PURE_OUI + volume_data.serial.lower(),
+            "nvme_nguid": _create_nguid(volume_data.serial.lower()),
+            "iops_limit": getattr(volume_data.qos, "iops_limit", 0),
+            "bandwidth_limit": getattr(volume_data.qos, "bandwidth_limit", 0),
+            "requested_promotion_state": volume_data.requested_promotion_state,
+            "promotion_status": volume_data.promotion_status,
+            "priority": getattr(volume_data, "priority", 0),
+            "priority_operator": "",
+            "priority_value": "",
+        }
+    }
+    if LooseVersion(PRIORITY_API_VERSION) <= LooseVersion(api_version):
+        volfact[volume_name][
+            "priority_operator"
+        ] = volume_data.priority_adjustment.priority_adjustment_operator
+        volfact[volume_name][
+            "priority_value"
+        ] = volume_data.priority_adjustment.priority_adjustment_value
+    return volfact
 
 
 def _create_nguid(serial):
@@ -348,54 +441,6 @@ def get_pgroup(module, array):
     return pgroup
 
 
-def human_to_bytes(size):
-    """Given a human-readable byte string (e.g. 2G, 30M),
-    return the number of bytes.  Will return 0 if the argument has
-    unexpected form.
-    """
-    bytes = size[:-1]
-    unit = size[-1].upper()
-    if bytes.isdigit():
-        bytes = int(bytes)
-        if unit == "P":
-            bytes *= 1125899906842624
-        elif unit == "T":
-            bytes *= 1099511627776
-        elif unit == "G":
-            bytes *= 1073741824
-        elif unit == "M":
-            bytes *= 1048576
-        elif unit == "K":
-            bytes *= 1024
-        else:
-            bytes = 0
-    else:
-        bytes = 0
-    return bytes
-
-
-def human_to_real(iops):
-    """Given a human-readable IOPs string (e.g. 2K, 30M),
-    return the real number.  Will return 0 if the argument has
-    unexpected form.
-    """
-    digit = iops[:-1]
-    unit = iops[-1].upper()
-    if unit.isdigit():
-        digit = iops
-    elif digit.isdigit():
-        digit = int(digit)
-        if unit == "M":
-            digit *= 1000000
-        elif unit == "K":
-            digit *= 1000
-        else:
-            digit = 0
-    else:
-        digit = 0
-    return digit
-
-
 def get_multi_volumes(module, destroyed=False):
     """Return True is all volumes exist or None"""
     names = []
@@ -500,7 +545,6 @@ def check_pod(module, array):
 
 def create_volume(module, array):
     """Create Volume"""
-    volfact = []
     changed = False
     api_version = array._list_available_rest_versions()
     if "/" in module.params["name"] and not check_vgroup(module, array):
@@ -538,17 +582,11 @@ def create_volume(module, array):
                         changed = True
                         if not module.check_mode:
                             try:
-                                volfact = array.create_volume(
+                                array.create_volume(
                                     module.params["name"],
                                     module.params["size"],
                                     bandwidth_limit=module.params["bw_qos"],
                                 )
-                                volfact["page83_naa"] = (
-                                    PURE_OUI + volfact["serial"].lower()
-                                )
-                                volfact["nvme_nguid"] = _create_nguid(
-                                    volfact["serial"].lower()
-                                )
                             except Exception:
                                 module.fail_json(
                                     msg="Volume {0} creation failed.".format(
@@ -570,17 +608,11 @@ def create_volume(module, array):
                         changed = True
                         if not module.check_mode:
                             try:
-                                volfact = array.create_volume(
+                                array.create_volume(
                                     module.params["name"],
                                     module.params["size"],
                                     iops_limit=module.params["iops_qos"],
                                 )
-                                volfact["page83_naa"] = (
-                                    PURE_OUI + volfact["serial"].lower()
-                                )
-                                volfact["nvme_nguid"] = _create_nguid(
-                                    volfact["serial"].lower()
-                                )
                             except Exception:
                                 module.fail_json(
                                     msg="Volume {0} creation failed.".format(
@@ -601,18 +633,12 @@ def create_volume(module, array):
                         changed = True
                         if not module.check_mode:
                             try:
-                                volfact = array.create_volume(
+                                array.create_volume(
                                     module.params["name"],
                                     module.params["size"],
                                     iops_limit=module.params["iops_qos"],
                                     bandwidth_limit=module.params["bw_qos"],
                                 )
-                                volfact["page83_naa"] = (
-                                    PURE_OUI + volfact["serial"].lower()
-                                )
-                                volfact["nvme_nguid"] = _create_nguid(
-                                    volfact["serial"].lower()
-                                )
                             except Exception:
                                 module.fail_json(
                                     msg="Volume {0} creation failed.".format(
@@ -631,17 +657,11 @@ def create_volume(module, array):
                         changed = True
                         if not module.check_mode:
                             try:
-                                volfact = array.create_volume(
+                                array.create_volume(
                                     module.params["name"],
                                     module.params["size"],
                                     bandwidth_limit=module.params["bw_qos"],
                                 )
-                                volfact["page83_naa"] = (
-                                    PURE_OUI + volfact["serial"].lower()
-                                )
-                                volfact["nvme_nguid"] = _create_nguid(
-                                    volfact["serial"].lower()
-                                )
                             except Exception:
                                 module.fail_json(
                                     msg="Volume {0} creation failed.".format(
@@ -658,13 +678,9 @@ def create_volume(module, array):
                     changed = True
                     if not module.check_mode:
                         try:
-                            volfact = array.create_volume(
+                            array.create_volume(
                                 module.params["name"], module.params["size"]
                             )
-                            volfact["page83_naa"] = PURE_OUI + volfact["serial"].lower()
-                            volfact["nvme_nguid"] = _create_nguid(
-                                volfact["serial"].lower()
-                            )
                         except Exception:
                             module.fail_json(
                                 msg="Volume {0} creation failed.".format(
@@ -675,17 +691,51 @@ def create_volume(module, array):
         changed = True
         if not module.check_mode:
             try:
-                volfact = array.create_volume(
-                    module.params["name"], module.params["size"]
-                )
-                volfact["page83_naa"] = PURE_OUI + volfact["serial"].lower()
-                volfact["nvme_nguid"] = _create_nguid(volfact["serial"].lower())
+                array.create_volume(module.params["name"], module.params["size"])
             except Exception:
                 module.fail_json(
                     msg="Volume {0} creation failed.".format(module.params["name"])
                 )
-
-    if module.params["pgroup"]:
+    if VOLUME_PROMOTION_API_VERSION in api_version and module.params["promotion_state"]:
+        arrayv6 = get_array(module)
+        volume = flasharray.VolumePatch(
+            requested_promotion_state=module.params["promotion_state"]
+        )
+        changed = True
+        if not module.check_mode:
+            res = arrayv6.patch_volumes(names=[module.params["name"]], volume=volume)
+            if res.status_code != 200:
+                arrayv6.patch_volumes(
+                    names=[module.params["name"]],
+                    volume=flasharray.VolumePatch(destroyed=True),
+                )
+                arrayv6.delete_volumes(names=[module.params["name"]])
+                module.fail_json(
+                    msg="Failed to set Promotion State for volume {0}.".format(
+                        module.params["name"]
+                    )
+                )
+    if PRIORITY_API_VERSION in api_version and module.params["priority_operator"]:
+        arrayv6 = get_array(module)
+        volume = flasharray.VolumePatch(
+            priority_adjustment=flasharray.PriorityAdjustment(
+                priority_adjustment_operator=module.params["priority_operator"],
+                priority_adjustment_value=module.params["priority_value"],
+            )
+        )
+        res = arrayv6.patch_volumes(names=[module.params["name"]], volume=volume)
+        if res.status_code != 200:
+            arrayv6.patch_volumes(
+                names=[module.params["name"]],
+                volume=flasharray.VolumePatch(destroyed=True),
+            )
+            arrayv6.delete_volumes(names=[module.params["name"]])
+            module.fail_json(
+                msg="Failed to set DMM Priority Adjustment on volume {0}. Error: {1}".format(
+                    module.params["name"], res.errors[0].message
+                )
+            )
+    if module.params["pgroup"] and DEFAULT_API_VERSION not in api_version:
         changed = True
         if not module.check_mode:
             try:
@@ -699,10 +749,10 @@ def create_volume(module, array):
                     )
                 )
 
-    module.exit_json(changed=changed, volume=volfact)
+    module.exit_json(changed=changed, volume=_volfact(module, arrayv6))
 
 
-def create_multi_volume(module, array):
+def create_multi_volume(module, array, single=False):
     """Create Volume"""
     volfact = {}
     changed = True
@@ -727,14 +777,17 @@ def create_multi_volume(module, array):
             if array.get_pod(pod_name)["promotion_status"] == "demoted":
                 module.fail_json(msg="Volume cannot be created in a demoted pod")
     array = get_array(module)
-    for vol_num in range(
-        module.params["start"], module.params["count"] + module.params["start"]
-    ):
-        names.append(
-            module.params["name"]
-            + str(vol_num).zfill(module.params["digits"])
-            + module.params["suffix"]
-        )
+    if not single:
+        for vol_num in range(
+            module.params["start"], module.params["count"] + module.params["start"]
+        ):
+            names.append(
+                module.params["name"]
+                + str(vol_num).zfill(module.params["digits"])
+                + module.params["suffix"]
+            )
+    else:
+        names.append(module.params["name"])
     if module.params["bw_qos"]:
         bw_qos = int(human_to_bytes(module.params["bw_qos"]))
         if bw_qos in range(1048576, 549755813888):
@@ -770,7 +823,29 @@ def create_multi_volume(module, array):
             subtype="regular",
         )
     if not module.check_mode:
-        res = array.post_volumes(names=names, volume=vols)
+        if DEFAULT_API_VERSION in api_version:
+            if module.params["add_to_pgs"]:
+                add_to_pgs = []
+                for add_pg in range(0, len(module.params["add_to_pgs"])):
+                    add_to_pgs.append(
+                        flasharray.FixedReference(
+                            name=module.params["add_to_pgs"][add_pg]
+                        )
+                    )
+                res = array.post_volumes(
+                    names=names,
+                    volume=vols,
+                    with_default_protection=module.params["with_default_protection"],
+                    add_to_protection_groups=add_to_pgs,
+                )
+            else:
+                res = array.post_volumes(
+                    names=names,
+                    volume=vols,
+                    with_default_protection=module.params["with_default_protection"],
+                )
+        else:
+            res = array.post_volumes(names=names, volume=vols)
         if res.status_code != 200:
             module.fail_json(
                 msg="Multi-Volume {0}#{1} creation failed: {2}".format(
@@ -780,6 +855,48 @@ def create_multi_volume(module, array):
                 )
             )
         else:
+            if (
+                VOLUME_PROMOTION_API_VERSION in api_version
+                and module.params["promotion_state"]
+            ):
+                volume = flasharray.VolumePatch(
+                    requested_promotion_state=module.params["promotion_state"]
+                )
+                prom_res = array.patch_volumes(names=names, volume=volume)
+                if prom_res.status_code != 200:
+                    array.patch_volumes(
+                        names=names,
+                        volume=flasharray.VolumePatch(destroyed=True),
+                    )
+                    array.delete_volumes(names=names)
+                    module.warn(
+                        "Failed to set promotion status on volumes. Error: {0}".format(
+                            prom_res.errors[0].message
+                        )
+                    )
+            if (
+                PRIORITY_API_VERSION in api_version
+                and module.params["priority_operator"]
+            ):
+                volume = flasharray.VolumePatch(
+                    priority_adjustment=flasharray.PriorityAdjustment(
+                        priority_adjustment_operator=module.params["priority_operator"],
+                        priority_adjustment_value=module.params["priority_value"],
+                    )
+                )
+                prio_res = array.patch_volumes(names=names, volume=volume)
+                if prio_res.status_code != 200:
+                    array.patch_volumes(
+                        names=names,
+                        volume=flasharray.VolumePatch(destroyed=True),
+                    )
+                    array.delete_volumes(names=names)
+                    module.fail_json(
+                        msg="Failed to set DMM Priority Adjustment on volumes. Error: {0}".format(
+                            prio_res.errors[0].message
+                        )
+                    )
+                prio_temp = list(prio_res.items)
             temp = list(res.items)
             for count in range(0, len(temp)):
                 vol_name = temp[count].name
@@ -798,8 +915,25 @@ def create_multi_volume(module, array):
                     ].qos.bandwidth_limit
                 if iops_qos_size != 0:
                     volfact[vol_name]["iops_limit"] = temp[count].qos.iops_limit
+                if (
+                    VOLUME_PROMOTION_API_VERSION in api_version
+                    and module.params["promotion_state"]
+                ):
+                    volfact[vol_name]["promotion_status"] = prio_temp[
+                        count
+                    ].promotion_status
+                if (
+                    PRIORITY_API_VERSION in api_version
+                    and module.params["priority_operator"]
+                ):
+                    volfact[vol_name]["priority_operator"] = prio_temp[
+                        count
+                    ].priority_adjustment.priority_adjustment_operator
+                    volfact[vol_name]["priority_value"] = prio_temp[
+                        count
+                    ].priority_adjustment.priority_adjustment_value
 
-    if module.params["pgroup"]:
+    if module.params["pgroup"] and DEFAULT_API_VERSION not in api_version:
         if not module.check_mode:
             res = array.post_protection_groups_volumes(
                 group_names=[module.params["pgroup"]], member_names=names
@@ -811,58 +945,110 @@ def create_multi_volume(module, array):
                     )
                 )
 
-    module.exit_json(changed=changed, volfact=volfact)
+    module.exit_json(changed=changed, volume=volfact)
 
 
 def copy_from_volume(module, array):
     """Create Volume Clone"""
-    volfact = []
     changed = False
     tgt = get_target(module, array)
-
+    api_version = array._list_available_rest_versions()
+    arrayv6 = get_array(module)
     if tgt is None:
         changed = True
         if not module.check_mode:
-            try:
-                volfact = array.copy_volume(
-                    module.params["name"], module.params["target"]
-                )
-                volfact["page83_naa"] = PURE_OUI + volfact["serial"].lower()
-                volfact["nvme_nguid"] = _create_nguid(volfact["serial"].lower())
-                changed = True
-            except Exception:
-                module.fail_json(
-                    msg="Copy volume {0} to volume {1} failed.".format(
-                        module.params["name"], module.params["target"]
+            if DEFAULT_API_VERSION in api_version:
+                if module.params["add_to_pgs"]:
+                    add_to_pgs = []
+                    for add_pg in range(0, len(module.params["add_to_pgs"])):
+                        add_to_pgs.append(
+                            flasharray.FixedReference(
+                                name=module.params["add_to_pgs"][add_pg]
+                            )
+                        )
+                    res = arrayv6.post_volumes(
+                        with_default_protection=module.params[
+                            "with_default_protection"
+                        ],
+                        add_to_protection_groups=add_to_pgs,
+                        names=[module.params["target"]],
+                        volume=flasharray.VolumePost(
+                            source=flasharray.Reference(name=module.params["name"])
+                        ),
+                    )
+                else:
+                    res = arrayv6.post_volumes(
+                        with_default_protection=module.params[
+                            "with_default_protection"
+                        ],
+                        names=[module.params["target"]],
+                        volume=flasharray.VolumePost(
+                            source=flasharray.Reference(name=module.params["name"])
+                        ),
+                    )
+
+                if res.status_code != 200:
+                    module.fail_json(
+                        msg="Failed to copy volume {0} to {1}. Error: {2}".format(
+                            module.params["name"],
+                            module.params["target"],
+                            res.errors[0].message,
+                        )
+                    )
+            else:
+                try:
+                    array.copy_volume(module.params["name"], module.params["target"])
+                    changed = True
+                except Exception:
+                    module.fail_json(
+                        msg="Copy volume {0} to volume {1} failed.".format(
+                            module.params["name"], module.params["target"]
+                        )
                     )
-                )
     elif tgt is not None and module.params["overwrite"]:
         changed = True
         if not module.check_mode:
-            try:
-                volfact = array.copy_volume(
-                    module.params["name"],
-                    module.params["target"],
-                    overwrite=module.params["overwrite"],
-                )
-                volfact["page83_naa"] = PURE_OUI + volfact["serial"].lower()
-                volfact["nvme_nguid"] = _create_nguid(volfact["serial"].lower())
-                changed = True
-            except Exception:
-                module.fail_json(
-                    msg="Copy volume {0} to volume {1} failed.".format(
-                        module.params["name"], module.params["target"]
+            if DEFAULT_API_VERSION not in api_version:
+                try:
+                    array.copy_volume(
+                        module.params["name"],
+                        module.params["target"],
+                        overwrite=module.params["overwrite"],
                     )
+                    changed = True
+                except Exception:
+                    module.fail_json(
+                        msg="Copy volume {0} to volume {1} failed.".format(
+                            module.params["name"], module.params["target"]
+                        )
+                    )
+            else:
+                res = arrayv6.post_volumes(
+                    overwrite=module.params["overwrite"],
+                    names=[module.params["target"]],
+                    volume=flasharray.VolumePost(
+                        source=flasharray.Reference(name=module.params["name"])
+                    ),
                 )
+                if res.status_code != 200:
+                    module.fail_json(
+                        msg="Failed to copy volume {0} to {1}. Error: {2}".format(
+                            module.params["name"],
+                            module.params["target"],
+                            res.errors[0].message,
+                        )
+                    )
 
-    module.exit_json(changed=changed, volume=volfact)
+    module.exit_json(changed=changed, volume=_volfact(module, arrayv6))
 
 
 def update_volume(module, array):
     """Update Volume size and/or QoS"""
-    volfact = []
     changed = False
+    arrayv6 = None
     api_version = array._list_available_rest_versions()
+    if MULTI_VOLUME_VERSION in api_version:
+        arrayv6 = get_array(module)
     vol = array.get_volume(module.params["name"])
     vol_qos = array.get_volume(module.params["name"], qos=True)
     if QOS_API_VERSION in api_version:
@@ -884,7 +1070,7 @@ def update_volume(module, array):
                 changed = True
                 if not module.check_mode:
                     try:
-                        volfact = array.extend_volume(
+                        array.extend_volume(
                             module.params["name"], module.params["size"]
                         )
                     except Exception:
@@ -894,14 +1080,14 @@ def update_volume(module, array):
                             )
                         )
     if module.params["bw_qos"] and QOS_API_VERSION in api_version:
-        if human_to_bytes(module.params["bw_qos"]) != vol_qos["bandwidth_limit"]:
+        if int(human_to_bytes(module.params["bw_qos"])) != int(
+            vol_qos["bandwidth_limit"]
+        ):
             if module.params["bw_qos"] == "0":
                 changed = True
                 if not module.check_mode:
                     try:
-                        volfact = array.set_volume(
-                            module.params["name"], bandwidth_limit=""
-                        )
+                        array.set_volume(module.params["name"], bandwidth_limit="")
                     except Exception:
                         module.fail_json(
                             msg="Volume {0} Bandwidth QoS removal failed.".format(
@@ -914,7 +1100,7 @@ def update_volume(module, array):
                 changed = True
                 if not module.check_mode:
                     try:
-                        volfact = array.set_volume(
+                        array.set_volume(
                             module.params["name"],
                             bandwidth_limit=module.params["bw_qos"],
                         )
@@ -931,12 +1117,12 @@ def update_volume(module, array):
                     )
                 )
     if module.params["iops_qos"] and IOPS_API_VERSION in api_version:
-        if human_to_real(module.params["iops_qos"]) != vol_qos["iops_limit"]:
+        if int(human_to_real(module.params["iops_qos"])) != int(vol_qos["iops_limit"]):
             if module.params["iops_qos"] == "0":
                 changed = True
                 if not module.check_mode:
                     try:
-                        volfact = array.set_volume(module.params["name"], iops_limit="")
+                        array.set_volume(module.params["name"], iops_limit="")
                     except Exception:
                         module.fail_json(
                             msg="Volume {0} IOPs QoS removal failed.".format(
@@ -947,7 +1133,7 @@ def update_volume(module, array):
                 changed = True
                 if not module.check_mode:
                     try:
-                        volfact = array.set_volume(
+                        array.set_volume(
                             module.params["name"], iops_limit=module.params["iops_qos"]
                         )
                     except Exception:
@@ -962,15 +1148,73 @@ def update_volume(module, array):
                         module.params["bw_qos"]
                     )
                 )
-    if not changed:
-        volfact = array.get_volume(module.params["name"])
-    module.exit_json(changed=changed, volume=volfact)
+    if VOLUME_PROMOTION_API_VERSION in api_version and module.params["promotion_state"]:
+        vol6 = list(arrayv6.get_volumes(names=[module.params["name"]]).items)[0]
+        if module.params["promotion_state"] != vol6.promotion_status:
+            volume_patch = flasharray.VolumePatch(
+                requested_promotion_state=module.params["promotion_state"]
+            )
+            changed = True
+            if not module.check_mode:
+                prom_res = arrayv6.patch_volumes(
+                    names=[module.params["name"]], volume=volume_patch
+                )
+                if prom_res.status_code != 200:
+                    module.fail_json(
+                        msg="Failed to change promotion status for volume {0}.".format(
+                            module.params["name"]
+                        )
+                    )
+    if PRIORITY_API_VERSION in api_version and module.params["priority_operator"]:
+        volv6 = list(arrayv6.get_volumes(names=[module.params["name"]]).items)[0]
+        change_prio = False
+        if (
+            module.params["priority_operator"]
+            != volv6.priority_adjustment.priority_adjustment_operator
+        ):
+            change_prio = True
+            newop = module.params["priority_operator"]
+        else:
+            newop = volv6.priority_adjustment.priority_adjustment_operator
+        if (
+            module.params["priority_value"]
+            and module.params["priority_value"]
+            != volv6.priority_adjustment.priority_adjustment_value
+        ):
+            change_prio = True
+            newval = module.params["priority_value"]
+        elif (
+            not module.params["priority_value"]
+            and volv6.priority_adjustment.priority_adjustment_value != 0
+        ):
+            change_prio = True
+            newval = 0
+        else:
+            newval = volv6.priority_adjustment.priority_adjustment_value
+        volumepatch = flasharray.VolumePatch(
+            priority_adjustment=flasharray.PriorityAdjustment(
+                priority_adjustment_operator=newop,
+                priority_adjustment_value=newval,
+            )
+        )
+        if change_prio and not module.check_mode:
+            changed = True
+            prio_res = arrayv6.patch_volumes(
+                names=[module.params["name"]], volume=volumepatch
+            )
+            if prio_res.status_code != 200:
+                module.fail_json(
+                    msg="Failed to change DMM Priority Adjustment for {0}. Error: {1}".format(
+                        module.params["name"], prio_res.errors[0].message
+                    )
+                )
+    module.exit_json(changed=changed, volume=_volfact(module, arrayv6))
 
 
 def rename_volume(module, array):
     """Rename volume within a container, ie pod, vgroup or local array"""
-    volfact = []
     changed = False
+    arrayv6 = get_array(module)
     pod_name = ""
     vgroup_name = ""
     target_name = module.params["rename"]
@@ -1012,9 +1256,7 @@ def rename_volume(module, array):
             changed = True
             if not module.check_mode:
                 try:
-                    volfact = array.rename_volume(
-                        module.params["name"], module.params["rename"]
-                    )
+                    array.rename_volume(module.params["name"], module.params["rename"])
                 except Exception:
                     module.fail_json(
                         msg="Rename volume {0} to {1} failed.".format(
@@ -1024,12 +1266,11 @@ def rename_volume(module, array):
     else:
         module.fail_json(msg="Target volume {0} already exists.".format(target_name))
 
-    module.exit_json(changed=changed, volume=volfact)
+    module.exit_json(changed=changed, volume=_volfact(module, arrayv6))
 
 
 def move_volume(module, array):
     """Move volume between pods, vgroups or local array"""
-    volfact = []
     changed = vgroup_exists = target_exists = pod_exists = False
     api_version = array._list_available_rest_versions()
     pod_name = ""
@@ -1126,7 +1367,7 @@ def move_volume(module, array):
     changed = True
     if not module.check_mode:
         try:
-            volfact = array.move_volume(module.params["name"], target_location)
+            array.move_volume(module.params["name"], target_location)
         except Exception:
             if target_location == "":
                 target_location = "[local]"
@@ -1135,28 +1376,30 @@ def move_volume(module, array):
                     module.params["name"], target_location
                 )
             )
-    module.exit_json(changed=changed, volume=volfact)
+    arrayv6 = get_array(module)
+    module.exit_json(changed=changed, volume=_volfact(module, arrayv6))
 
 
 def delete_volume(module, array):
     """Delete Volume"""
     changed = True
-    volfact = []
     if not module.check_mode:
         try:
             array.destroy_volume(module.params["name"])
             if module.params["eradicate"]:
                 try:
-                    volfact = array.eradicate_volume(module.params["name"])
+                    array.eradicate_volume(module.params["name"])
                 except Exception:
                     module.fail_json(
                         msg="Eradicate volume {0} failed.".format(module.params["name"])
                     )
+                module.exit_json(changed=changed, volume=[])
         except Exception:
             module.fail_json(
                 msg="Delete volume {0} failed.".format(module.params["name"])
             )
-    module.exit_json(changed=changed, volume=volfact)
+    arrayv6 = get_array(module)
+    module.exit_json(changed=changed, volume=_volfact(module, arrayv6))
 
 
 def eradicate_volume(module, array):
@@ -1177,7 +1420,6 @@ def eradicate_volume(module, array):
 def recover_volume(module, array):
     """Recover Deleted Volume"""
     changed = True
-    volfact = []
     if not module.check_mode:
         try:
             array.recover_volume(module.params["name"])
@@ -1185,7 +1427,9 @@ def recover_volume(module, array):
             module.fail_json(
                 msg="Recovery of volume {0} failed".format(module.params["name"])
             )
-    module.exit_json(changed=changed, volume=volfact)
+        array.get_volume(module.params["name"])
+    arrayv6 = get_array(module)
+    module.exit_json(changed=changed, volume=_volfact(module, arrayv6))
 
 
 def main():
@@ -1205,8 +1449,13 @@ def main():
             count=dict(type="int"),
             start=dict(type="int", default=0),
             digits=dict(type="int", default=1),
-            suffix=dict(type="str"),
+            suffix=dict(type="str", default=""),
+            priority_operator=dict(type="str", choices=["+", "-", "="]),
+            priority_value=dict(type="int", choices=[-10, 0, 10]),
             size=dict(type="str"),
+            with_default_protection=dict(type="bool", default=True),
+            add_to_pgs=dict(type="list", elements="str"),
+            promotion_state=dict(type="str", choices=["promoted", "demoted"]),
         )
     )
 
@@ -1215,9 +1464,13 @@ def main():
         ["move", "rename", "target", "eradicate"],
         ["rename", "move", "target", "eradicate"],
     ]
+    required_together = [["priority_operator", "priority_value"]]
 
     module = AnsibleModule(
-        argument_spec, mutually_exclusive=mutually_exclusive, supports_check_mode=True
+        argument_spec,
+        mutually_exclusive=mutually_exclusive,
+        required_together=required_together,
+        supports_check_mode=True,
     )
 
     size = module.params["size"]
@@ -1315,8 +1568,15 @@ def main():
             module.warn("Method not yet supported for multi-volume")
     else:
         if state == "present" and not volume and not destroyed and size:
-            create_volume(module, array)
-        elif state == "present" and volume and (size or bw_qos or iops_qos):
+            if DEFAULT_API_VERSION in api_version:
+                create_multi_volume(module, array, True)
+            else:
+                create_volume(module, array)
+        elif (
+            state == "present"
+            and volume
+            and (size or bw_qos or iops_qos or module.params["promotion_state"])
+        ):
             update_volume(module, array)
         elif state == "present" and not volume and module.params["move"]:
             module.fail_json(
